#!/usr/bin/env python3
# coding: utf-8

"""
Description: Compile operation
Create: 2021-02-18
Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
"""

import sys
import os
from tools import common
from tools import utils


class Compiler(object):
    """ 
    编译相关操作
    """
    @staticmethod
    def compile(): 
        hightec_toolchain_path = os.path.join(common.PROJ_TOP_DIR,
                                              "cmake/hightec_toolchain.cmake")
        if not os.path.exists(hightec_toolchain_path):
            utils.show_err("hightec_toolchain is not exists")

        cmake_cmd = """cd {};
                    cmake -G "Unix Makefiles" \
                    -DCMAKE_TOOLCHAIN_FILE={} \
                     {} -DPROJ_EXECUTE_NAME={}""".format(
                                  common.PROJ_BUILD_TMP_DIR,
                                  hightec_toolchain_path,
                                  common.PROJ_TOP_DIR,
                                  common.PROJ_EXECUTE_NAME)
        cmake_cmd = cmake_cmd + " "
        if utils.execute_process(cmake_cmd) != 0:
            utils.show_err("Do cmake failed!")
            return False

        make_clean_cmd = "cd {}; \
                         make -f Makefile clean".format(
                             common.PROJ_BUILD_TMP_DIR)
        if utils.execute_process(make_clean_cmd) != 0:
            utils.show_err("Do make clean failed!")
            return False

        make_cmd = "cd {}; \
                    make -f Makefile -j 16".format(
                        common.PROJ_BUILD_TMP_DIR)
        if utils.execute_process(make_cmd) != 0:
            utils.show_err("Do make failed!")
            return False

        return True
    
    def run(self):
        """编译入口"""
        if not self.compile():
            utils.show_err("Do compiling failed!")
            return False

        return True