function(mdc_message)
  if(NOT WIN32)
    string(ASCII 27 esc)
    set(red          "${esc}[31m")
    set(green        "${esc}[32m")
    set(yellow       "${esc}[33m")
    set(blue         "${esc}[34m")
    set(magenta      "${esc}[35m")
    set(cyan         "${esc}[36m")
    set(white        "${esc}[37m")
    set(bold_red     "${esc}[1;31m")
    set(bold_green   "${esc}[1;32m")
    set(bold_yellow  "${esc}[1;33m")
    set(bold_blue    "${esc}[1;34m")
    set(bold_magenta "${esc}[1;35m")
    set(bold_cyan    "${esc}[1;36m")
    set(bold_white   "${esc}[1;37m")
    set(reset_color  "${esc}[m")
    set(bold_color   "${esc}[1m")
  endif()

  list(GET ARGV 0 level)
  if(level STREQUAL FATAL_ERROR OR level STREQUAL SEND_ERROR)
    list(REMOVE_AT ARGV 0)
    message(${level} "${bold_red}${ARGV}${reset_color}")
  elseif(level STREQUAL WARNING)
    list(REMOVE_AT ARGV 0)
    message(${level} "${bold_yellow}${ARGV}${reset_color}")
  elseif(level STREQUAL AUTHOR_WARNING)
    list(REMOVE_AT ARGV 0)
    message(${level} "${bold_cyan}${ARGV}${reset_color}")
  elseif(level STREQUAL STATUS)
    list(REMOVE_AT ARGV 0)
    message(${level} "${green}${ARGV}${reset_color}")
  else()
    message("${ARGV}")
  endif()
endfunction()

function(mdc_glob files)
  set(opts)

  set(single_args
    NAME
  )

  set(multi_args
    INCLUDES
    EXCLUDES
  )

  cmake_parse_arguments(MDC_GLOB "${opts}" "${single_args}" "${multi_args}" ${ARGN})

  if(MDC_GLOB_UNPARSED_ARGUMENTS)
    mdc_message(FATAL_ERROR "unknown keywords given to mdc_glob(): \"${MDC_GLOB_UNPARSED_ARGUMENTS}\"")
    return()
  endif()

  if(NOT MDC_GLOB_NAME)
    mdc_message(FATAL_ERROR "required keyword NAME missing for mdc_glob() function")
    return()
  endif()

  if(NOT MDC_GLOB_INCLUDES)
    mdc_message(FATAL_ERROR "required keyword INCLUDES missing for mdc_glob() function")
    return()
  endif()

  foreach(file IN LISTS MDC_GLOB_INCLUDES)
    string(FIND ${file} "*" result)
    if (result EQUAL -1)  # not glob
      string(FIND ${file} "/" result)
      if(result EQUAL 0)
        if(NOT EXISTS ${file})
          mdc_message(FATAL_ERROR "not found ${file}")
          return()
        endif()
        list(APPEND absolute_files ${file})
      else()
        if(NOT EXISTS ${CMAKE_CURRENT_SOURCE_DIR}/${file})
          mdc_message(FATAL_ERROR "not found ${file} in ${CMAKE_CURRENT_SOURCE_DIR}")
          return()
        endif()
        list(APPEND relative_files ${file})
      endif()
    else()   # glob
      string(FIND ${file} "/" result)
      if(result EQUAL 0)
        list(APPEND absolute_globs ${file})
      else()
        list(APPEND relative_globs ${file})
      endif()
    endif()
  endforeach()

  if(absolute_globs)
    file(GLOB_RECURSE absolute_glob_files CONFIGURE_DEPENDS
      ${absolute_globs}
    )
    list(APPEND absolute_files ${absolute_glob_files})
  endif()

  if(relative_globs)
    file(GLOB_RECURSE relative_glob_files RELATIVE ${CMAKE_CURRENT_SOURCE_DIR} CONFIGURE_DEPENDS
      ${relative_globs}
    )
    list(APPEND relative_files ${relative_glob_files})
  endif()

  foreach(exclude_file IN LISTS MDC_GLOB_EXCLUDES)
    if(IS_ABSOLUTE ${exclude_file})
      if(EXISTS ${exclude_file})
        list(REMOVE_ITEM absolute_files ${exclude_file})
      else()
        mdc_message(FATAL_ERROR "EXCLUDES invalid: ${exclude_file} is not exist")
        return()
      endif()
    else()
      if(EXISTS ${CMAKE_CURRENT_SOURCE_DIR}/${exclude_file})
        list(REMOVE_ITEM relative_files ${exclude_file})
      else()
        mdc_message(FATAL_ERROR "EXCLUDES invalid: ${CMAKE_CURRENT_SOURCE_DIR}/${exclude_file} is not exist")
        return()
      endif()
    endif()
  endforeach()

  list(APPEND all_files ${absolute_files} ${relative_files})

  set(${files} ${all_files} PARENT_SCOPE)

  if(NOT all_files)
    mdc_message(WARNING "not found any files in ${CMAKE_CURRENT_SOURCE_DIR} | includes: ${MDC_GLOB_INCLUDES} | exculdes: ${MDC_GLOB_EXCLUDES}")
  endif()
endfunction()

function(StaticLibTargetGen target_name)
    set(options OPTIONS)
    set(one_args args1)
    set(multi_args
        SRCS
        EXCLUDES
        INCS
        DEPS
        CDEFS
        COPTS
        LOPTS
        LPATHS
        OUTPUT
    )
    cmake_parse_arguments(MCU_LIBRARY_STATIC "${options}" "%{one_args}" "${multi_args}" ${ARGN})

    add_library(${target_name})
    if(MCU_LIBRARY_STATIC_SRCS)
        mdc_glob(srcs
            NAME
                ${target_name}
            INCLUDES
                ${MCU_LIBRARY_STATIC_SRCS}
        )

        target_sources(${target_name}
            PRIVATE
            ${srcs}
        )
  endif()
    
    set_target_properties(${target_name} PROPERTIES ARCHIVE_OUTPUT_DIRECTORY ${MCU_LIBRARY_STATIC_OUTPUT})
    target_compile_options(${target_name} PRIVATE ${SAFETYOS_COMPIEL_OPTION})
    target_compile_definitions(${target_name} PRIVATE ${SAFETYOS_COMPILE_DEFINITIONS})
    target_include_directories(${target_name} PRIVATE ${MCU_LIBRARY_STATIC_INCS})
endfunction()


function(target_properties target_name)
    set(one_args args1)
    set(multi_args
        PUB_INCS
        LIB_DIR
    )
    cmake_parse_arguments(MCU_LIBRARY_STATIC "${options}" "%{one_args}" "${multi_args}" ${ARGN})
    target_include_directories(${target_name} PUBLIC ${MCU_LIBRARY_STATIC_PUB_INCS})
    set_target_properties(${target_name} PROPERTIES ARCHIVE_OUTPUT_DIRECTORY ${MCU_LIBRARY_STATIC_LIB_DIR})
endfunction()