/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.
 * Description: ncs头文件
 * Author: huawei
 */
#ifndef NCS_CP_H
#define NCS_CP_H

#include "PlatformTypes.h"
#include "Rte_Type.h"
#include "detection_helper.h"

#define NCS_FVM_FV_LEN                      8U
#define NCS_MON_FV_NVM_OPERATION_WRITE  0U
#define NCS_MON_FV_NVM_OPERATION_DUMP   1U

typedef struct {
    uint16 Id;
    uint8 states;
    uint8 len;
    uint8 dumpValue[NCS_FVM_FV_LEN];                    /* 这个是从nvm中dump出来的新鲜值，是可以真正使用的新鲜值 */
    uint8 writeValue[NCS_FVM_FV_LEN];                   /* 这个是FVM请求写入NVM的新鲜值 */
} Freshness;

typedef struct {
    uint8 blockId;
    uint8 busStatus;
} FvNvmBlockStates;

typedef struct {
    Freshness fv;               /* 新鲜值信息 */
    FvNvmBlockStates nvmOpt;    /* 新鲜值存储及状态信息 */
} FreshnessNode;

typedef struct {
    uint16 fvId;
    uint8 nvmOperation;
    CounterDebounce debounce;
} FvmClientFaultDetectType;

typedef struct {
    uint8 freshNodeNum;
    uint8 fvmDetectionNum;
    FreshnessNode *freshNodes;
    FvmClientFaultDetectType *fvmDetections;
} FvmClientCfgType;

#define NCS_MON_SECOC_RX_OPERATION_MAC   0U
#define NCS_MON_SECOC_RX_OPERATION_FV    1U
#define NCS_MON_SECOC_RX_OPERATION_ALL   2U

typedef struct {
    uint16 msgId;
    uint8 secocOperation;
    CounterDebounce debounce;
} SecocFaultDetectType;

typedef struct {
    uint16  msgId;
    uint8   status;
    boolean isPassedMsg;   // 校验失败也将数据传到上层
} RxMsgCfgType;

typedef struct {
    uint8 secocDetectionNum;
    uint8 rxMsgNum;
    uint8 txMsgNum;
    SecocFaultDetectType *secocDetections;
    RxMsgCfgType* rxMsgs;
    uint16* txMsgs;
} SecocCfgType;

/* Key更新时的生效方式：0：更新后立刻生效(默认)，:1：更新后重启生效 */
typedef uint8 NcsKeyActiveType;
#define NCS_KEY_UPDATE_ACTIVE               ((NcsKeyActiveType)0)        /* 密钥更新立马生效; */
#define NCS_KEY_RESET_ACTIVE                ((NcsKeyActiveType)1)        /* 密钥更新重启生效; */

/* Key更新是否有密钥挑战步骤 */
typedef uint8 NcsKeyChallengeStepType;
#define NCS_KEY_CHALLENGE_INVALID           ((NcsKeyChallengeStepType)0) /* 密钥更新过程中无密钥挑战步骤; */
#define NCS_KEY_CHALLENGE_VALID             ((NcsKeyChallengeStepType)1) /* 密钥更新过程中有密钥挑战步骤; */

/* 密钥备份标志：单一密钥时，默认使用主密钥槽位；备份密钥时，激活密钥配置选择有效的密钥槽位 */
typedef uint8 NcsBackupType;
#define NCS_KEY_BACKUP_TYPE_SINGLE          ((NcsBackupType)0)
#define NCS_KEY_BACKUP_TYPE_DUAL            ((NcsBackupType)1)

/* Key的拥有者: KeyAttributes.keyAthor ; */
typedef uint8 NcsKeyAuthor;
#define NCS_KEY_AUTHOR_NONE                 ((NcsKeyAuthor)0)        /* 初始状态; */
#define NCS_KEY_AUTHOR_SECOC                ((NcsKeyAuthor)1)        /* SecOC使用的密钥; */
#define NCS_KEY_AUTHOR_PRESET               ((NcsKeyAuthor)2)        /* 产线预置对称密钥; */
#define NCS_KEY_AUTHOR_DIAG                 ((NcsKeyAuthor)3)        /* 独立诊断接入使用的密钥; */
#define NCS_KEY_AUTHOR_SAM                  ((NcsKeyAuthor)4)        /* 传感器认证使用的密钥; */
#define NCS_KEY_AUTHOR_TLS                  ((NcsKeyAuthor)5)        /* TLS使用的密钥; */
#define NCS_KEY_AUTHOR_LWATP                ((NcsKeyAuthor)6)        /* LWATP使用的密钥; */

/* Key的状态: KeySlotAttributes.keyStatus ; */
typedef uint8 NcsKeyStatus;
#define NCS_KEY_STATUS_INIT                 ((NcsKeyStatus)0)        /* 初始状态; */
#define NCS_KEY_STATUS_ACTIVE               ((NcsKeyStatus)1)        /* 已验证有效; */
#define NCS_KEY_STATUS_INACTIVE             ((NcsKeyStatus)2)        /* 已验证无效; */
#define NCS_KEY_STATUS_UPDATING             ((NcsKeyStatus)3)        /* 密钥更新中; */
#define NCS_KEY_STATUS_UPDATE_SUCCESS       ((NcsKeyStatus)4)        /* 密钥更新完成; */
#define NCS_KEY_STATUS_UPDATE_FAILED        ((NcsKeyStatus)5)        /* 密钥更新失败; */

/* 定义密钥状态变更的通知函数，需要被动获取密钥状态变化时使用 */
typedef Std_ReturnType (*KeyStatusObserver)(NcsKeyAuthor keyAuthor,
    NcsKeyStatus majorKeyStatus, NcsKeyStatus minorkeyStatus);

typedef struct {
    NcsKeyActiveType activeType;
    NcsKeyChallengeStepType challengeStepType;
    NcsBackupType backupType;
} SecocKeyCfgType;

#define NCS_SECOC_SW_ON                         (1U)
#define NCS_SECOC_SW_OFF                        (2U)
#define NCS_SECOC_SW_INVALID                    (0xFFU)
typedef struct {
    boolean enableFvmClient;    // 是否使能非vos的 fvm
    boolean enableSecoc;        // 是否使能secoc功能
    boolean enableSyncRxMsg;    // 是否使能vos 同步报文
    uint8   secocDefaultSw;     // secoc默认校验状态
    uint16  syncRxMsgId;        // enableSyncRxMsg为true时 同步报文ID
    FvmClientCfgType* fvmCfg;
    SecocCfgType* secocCfg;
    SecocKeyCfgType* secocKeyCfg;
} NcsCpCfgType;

void Ncs_Init(const NcsCpCfgType* ncsCfg);
void NcsSecocVerificationStatusCallout(SecOC_VerificationStatusType verificationStatus);
void NcsSecocDetCallout(uint16 moduleId, uint8 instanceId, uint8 apiId, uint8 errorId);

void NcsSyncMsgCheckSuccessNotify(void);
void NcsSyncMsgCheckFailedNotify(void);
void NcsSyncMsgStoreSuccessNotify(void);
void NcsSyncMsgStoreFailedNotify(void);

uint8 NcsSetSecocVerificationStatus(uint8 verificationStatusFlage);
uint8 NcsGetSecocVerifyStatus(void);

uint8 NcsNvMBlockSecocSwCallback(uint8 request, uint8 result);
uint8 NcsNvMBlockVinCodeCallback(uint8 request, uint8 result);
void NcsGetVinCode(uint8* data, uint32* len);
#endif