/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved.
 * Description:
 * Author: huawei
 */
#ifndef SCHM_CP_INTERNAL_H
#define SCHM_CP_INTERNAL_H

#include "Std_Types.h"
#include "Rte_Type.h"
#include "mcu_platform.h"


#define SCHM_CORE_NUM ((uint8)(6u))
#define SCHM_OS_TRACE_FAULT_ID_1MS_TASK ((uint32)(0u))
#define SCHM_OS_TRACE_FAULT_ID_5MS_TASK ((uint32)(1u))
#define SCHM_OS_TRACE_FAULT_ID_10MS_M_TASK ((uint32)(2u))
#define SCHM_OS_TRACE_FAULT_ID_ERRORHOOK4 ((uint32)(3u))
#define SCHM_OS_TRACE_FAULT_ID_ERRORHOOK4_1 ((uint32)(4u))
#define SCHM_OS_TRACE_FAULT_ID_ERRORHOOK4_2 ((uint32)(5u))
#define SCHM_OS_TRACE_FAULT_ID_ERRORHOOK4_3 ((uint32)(6u))
#define SCHM_OS_TRACE_FAULT_ID_INVALID ((uint32)(0xffffffffu))
#define SCHM_FAULT_NUM ((uint8)(7u))

#define TASK_ID_MAX ((uint16)(0xffffu))
#define RUNNABLE_ID_MAX ((uint16)(0xffffu))
#define ARTI_RUNNABLE_START ((uint8)(0xC0))
#define ARTI_RUNNABLE_END ((uint8)(0xC1))

#define SECOND2DIV(secs, tickMs) ((secs) * (uint32)(1000u) / (tickMs))


typedef struct {
    uint16 swcId;
    uint16 runnableId;
} SwcMappingType;

typedef struct {
    const uint32 faultUpdateThr[SCHM_FAULT_NUM];
    boolean isLogSendEnable;
    boolean isRteTraceEnable;
    const SwcMappingType *swcMappingCfg;
    uint16 sidCfg;
    uint16 ridCfg;
    uint16 tidCfg;
    uint16 mappingIdCfg;
} SchmRteCfgType;


void SchMOsTraceRecordTraceData(uint16 taskId, uint16 runnableId, uint8 traceType, uint8 coreId);
Std_ReturnType SchMOsTraceFaultReport(uint32 faultId);
void SchMOsTraceFaultHandleMainfunction(void);
void SchMOsTraceSendLogIf(void);

/* timing monitor api */
void SchMTimMonitorEntEcumInitZero(void);
void SchMTimMonitorExitEcumInitZero(void);
void SchMTimMonitorEntEcumInitOne(void);
void SchMTimMonitorExitEcumInitOne(void);
void SchMTimMonitorEntEcumInitBswmQM(void);
void SchMTimMonitorExitEcumInitBswmQM(void);
void SchMTimMonitorEntEcumInitBswmD(void);
void SchMTimMonitorExitEcumInitBswmD(void);
void SchMTimMonitorOsaCore0InitTaskD(uint8 checkPoint);
void SchMTimMonitorOsaCore0InitTaskQM(uint8 checkPoint);

void SchMTimMonitorMainfunction(void);

void SchMLogHandleMainFunction(void);
void SchMTimAnlysLoadMonitorIf(void);
void Schm_Init(const SchmRteCfgType *schmCfg);

void SchMErrorHookPrint(void);
void SchMErrorHook(uint8 error);

#endif