/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.
 * Description: The header file of E2E Library including all common definitions
 * Create: 2019-06-17
 */

#ifndef E2E_H
#define E2E_H

#include "Std_Types.h"
#include "E2E_TypeDefine.h"

#ifdef ENABLE_MEMMAP
#define E2E_START_SEC_CODE
#include "E2E_MemMap.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif
/**
* @file
*
* @brief The header file of E2E Library including all common definitions
*/
#ifdef ENABLE_VERSION_INFO
#define E2E_MODULE_ID ((uint16)207U)
#define E2E_VENDOR_ID (0x007F)
#define E2E_SW_MAJOR_SOURCE_VERSION (3U)
#define E2E_SW_MINOR_SOURCE_VERSION (2U)
#define E2E_SW_PATCH_SOURCE_VERSION (224U)
#endif
/* ---------------------- The structure of ProtectStateType for the Profile 1, 2, 5, 6, 11, 22 ---------------------- */
typedef struct {
    uint8 Counter;
} E2E_PXXProtectStateType_8bits;

/* ----------------------------------------- Type definitions for Profile 1 ----------------------------------------- */
typedef enum {
    E2E_P01_DATAID_BOTH = 0,
    E2E_P01_DATAID_ALT = 1,
    E2E_P01_DATAID_LOW = 2,
    E2E_P01_DATAID_NIBBLE = 3
} E2E_P01DataIDMode;

typedef struct {
    uint16 CounterOffset;
    uint16 CRCOffset;
    uint16 DataID;
    uint16 DataIDNibbleOffset;
    E2E_P01DataIDMode DataIDMode;
    uint16 DataLength;
    uint8 MaxDeltaCounterInit;
    uint8 MaxNoNewOrRepeatedData;
    uint8 SyncCounterInit;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P01ConfigType;

typedef  E2E_PXXProtectStateType_8bits E2E_P01ProtectStateType;

typedef enum {
    E2E_P01STATUS_OK = 0x00,
    E2E_P01STATUS_NONEWDATA = 0x01,
    E2E_P01STATUS_WRONGCRC = 0x02,
    E2E_P01STATUS_SYNC = 0x03,
    E2E_P01STATUS_INITIAL = 0x04,
    E2E_P01STATUS_REPEATED = 0x08,
    E2E_P01STATUS_OKSOMELOST = 0x20,
    E2E_P01STATUS_WRONGSEQUENCE = 0x40
} E2E_P01CheckStatusType;

typedef struct {
    uint8 LastValidCounter;
    uint8 MaxDeltaCounter;
    boolean WaitForFirstData;
    boolean NewDataAvailable;
    uint8 LostData;
    E2E_P01CheckStatusType Status;
    uint8 SyncCounter;
    uint8 NoNewOrRepeatedDataCounter;
} E2E_P01CheckStateType;

/* ----------------------------------------- Type definitions for Profile 2 ----------------------------------------- */
typedef struct {
    uint16 DataLength;
    uint8  DataIDList[E2E_DATAIDLIST_LENGTH];
    uint8 MaxDeltaCounterInit;
    uint8 MaxNoNewOrRepeatedData;
    uint8 SyncCounterInit;
    uint16 Offset;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P02ConfigType;

typedef  E2E_PXXProtectStateType_8bits E2E_P02ProtectStateType;

typedef enum {
    E2E_P02STATUS_OK = 0x00,
    E2E_P02STATUS_NONEWDATA = 0x01,
    E2E_P02STATUS_WRONGCRC = 0x02,
    E2E_P02STATUS_SYNC = 0x03,
    E2E_P02STATUS_INITIAL = 0x04,
    E2E_P02STATUS_REPEATED = 0x08,
    E2E_P02STATUS_OKSOMELOST = 0x20,
    E2E_P02STATUS_WRONGSEQUENCE = 0x40
} E2E_P02CheckStatusType;

typedef struct {
    uint8 LastValidCounter;
    uint8 MaxDeltaCounter;
    boolean WaitForFirstData;
    boolean NewDataAvailable;
    uint8 LostData;
    E2E_P02CheckStatusType Status;
    uint8 SyncCounter;
    uint8 NoNewOrRepeatedDataCounter;
} E2E_P02CheckStateType;

/* ----------------------------------------- Type definitions for Profile 4 ----------------------------------------- */
typedef struct {
    uint32 DataID;
    uint16 Offset;
    uint16 MinDataLength;
    uint16 MaxDataLength;
    uint16 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P04ConfigType;

typedef struct {
    uint16 Counter;
} E2E_P04ProtectStateType;

#ifdef ENABLE_E2E_P04_EXERRCODE
typedef enum {
    E2E_P04STATUS_OK = 0x00,
    E2E_P04STATUS_NONEWDATA = 0x01,
    E2E_P04STATUS_CRCERROR = 0x07,
    E2E_P04STATUS_REPEATED = 0x08,
    E2E_P04STATUS_OKSOMELOST = 0x20,
    E2E_P04STATUS_WRONGSEQUENCE = 0x40,
    E2E_P04STATUS_TIMEOUT = 0x50,
    E2E_P04STATUS_DIDERROR = 0x60,
    E2E_P04STATUS_DLENERROR = 0x70,
} E2E_P04CheckStatusType;
#else
typedef enum {
    E2E_P04STATUS_OK = 0x00,
    E2E_P04STATUS_NONEWDATA = 0x01,
    E2E_P04STATUS_ERROR = 0x07,
    E2E_P04STATUS_REPEATED = 0x08,
    E2E_P04STATUS_OKSOMELOST = 0x20,
    E2E_P04STATUS_WRONGSEQUENCE = 0x40,
    E2E_P04STATUS_TIMEOUT = 0x50
} E2E_P04CheckStatusType;
#endif

typedef struct {
    E2E_P04CheckStatusType Status;
    uint16 Counter;
} E2E_P04CheckStateType;
/* ----------------------------------------- Type definitions for Profile 44 --------------------------------------- */
typedef struct {
    uint32 DataID;
    uint32 Offset;
    uint32 MinDataLength;
    uint32 MaxDataLength;
    uint16 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P44ConfigType;

typedef struct {
    uint16 Counter;
} E2E_P44ProtectStateType;

typedef enum {
    E2E_P44STATUS_OK = 0x00,
    E2E_P44STATUS_NONEWDATA = 0x01,
    E2E_P44STATUS_ERROR = 0x07,
    E2E_P44STATUS_REPEATED = 0x08,
    E2E_P44STATUS_OKSOMELOST = 0x20,
    E2E_P44STATUS_WRONGSEQUENCE = 0x40,
    E2E_P44STATUS_TIMEOUT = 0x50
} E2E_P44CheckStatusType;

typedef struct {
    E2E_P44CheckStatusType Status;
    uint16 Counter;
} E2E_P44CheckStateType;

/* ----------------------------------------- Type definitions for Profile 4M ---------------------------------------- */
typedef struct {
    uint32 DataID;
    uint16 Offset;
    uint16 MinDataLength;
    uint16 MaxDataLength;
    uint16 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
    uint32 SourceID;
} E2E_P04mConfigType;

typedef struct {
    uint16 Counter;
} E2E_P04mProtectStateType;

typedef enum {
    E2E_P04MSTATUS_OK = 0x00,
    E2E_P04MSTATUS_NONEWDATA = 0x01,
    E2E_P04MSTATUS_ERROR = 0x07,
    E2E_P04MSTATUS_REPEATED = 0x08,
    E2E_P04MSTATUS_OKSOMELOST = 0x20,
    E2E_P04MSTATUS_WRONGSEQUENCE = 0x40,
    E2E_P04MSTATUS_TIMEOUT = 0x50
} E2E_P04mCheckStatusType;

typedef struct {
    E2E_P04mCheckStatusType Status;
    uint16 Counter;
} E2E_P04mCheckStateType;

/* ----------------------------------------- Type definitions for Profile 5 ----------------------------------------- */
typedef struct {
    uint16 Offset;
    uint16 DataLength;
    uint16 DataID;
    uint8 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P05ConfigType;

typedef E2E_PXXProtectStateType_8bits E2E_P05ProtectStateType;

typedef enum {
    E2E_P05STATUS_OK = 0x00,
    E2E_P05STATUS_NONEWDATA = 0x01,
    E2E_P05STATUS_ERROR = 0x07,
    E2E_P05STATUS_REPEATED = 0x08,
    E2E_P05STATUS_OKSOMELOST = 0x20,
    E2E_P05STATUS_WRONGSEQUENCE = 0x40,
    E2E_P05STATUS_TIMEOUT = 0x50
} E2E_P05CheckStatusType;

typedef struct {
    E2E_P05CheckStatusType Status;
    uint8 Counter;
} E2E_P05CheckStateType;

/* ----------------------------------------- Type definitions for Profile 6 ----------------------------------------- */
typedef struct {
    uint16 Offset;
    uint16 MinDataLength;
    uint16 MaxDataLength;
    uint16 DataID;
    uint8 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P06ConfigType;

typedef  E2E_PXXProtectStateType_8bits E2E_P06ProtectStateType;

typedef enum {
    E2E_P06STATUS_OK = 0x00,
    E2E_P06STATUS_NONEWDATA = 0x01,
    E2E_P06STATUS_ERROR = 0x07,
    E2E_P06STATUS_REPEATED = 0x08,
    E2E_P06STATUS_OKSOMELOST = 0x20,
    E2E_P06STATUS_WRONGSEQUENCE = 0x40,
    E2E_P06STATUS_TIMEOUT = 0x50
} E2E_P06CheckStatusType;

typedef struct {
    E2E_P06CheckStatusType Status;
    uint8 Counter;
} E2E_P06CheckStateType;

/* ----------------------------------------- Type definitions for Profile 7 ----------------------------------------- */
typedef struct {
    uint32 DataID;
    uint32 Offset;
    uint32 MinDataLength;
    uint32 MaxDataLength;
    uint32 MaxDeltaCounter;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P07ConfigType;

typedef struct {
    uint32 Counter;
} E2E_P07ProtectStateType;

typedef enum {
    E2E_P07STATUS_OK = 0x00,
    E2E_P07STATUS_NONEWDATA = 0x01,
    E2E_P07STATUS_ERROR = 0x07,
    E2E_P07STATUS_REPEATED = 0x08,
    E2E_P07STATUS_OKSOMELOST = 0x20,
    E2E_P07STATUS_WRONGSEQUENCE = 0x40,
    E2E_P07STATUS_TIMEOUT = 0x50
} E2E_P07CheckStatusType;

typedef struct {
    E2E_P07CheckStatusType Status;
    uint32 Counter;
} E2E_P07CheckStateType;

/* ----------------------------------------- Type definitions for Profile 11 ---------------------------------------- */
typedef enum {
    E2E_P11_DATAID_BOTH = 0,
    E2E_P11_DATAID_ALT = 1,
    E2E_P11_DATAID_LOW = 2,
    E2E_P11_DATAID_NIBBLE = 3
} E2E_P11DataIDMode;

typedef struct {
    uint16 DataLength;
    uint16 DataID;
    uint8 MaxDeltaCounter;
    E2E_P11DataIDMode DataIDMode;
    uint16 CRCOffset;
    uint16 CounterOffset;
    uint16 DataIDNibbleOffset;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P11ConfigType;

typedef  E2E_PXXProtectStateType_8bits E2E_P11ProtectStateType;

typedef enum {
    E2E_P11STATUS_OK = 0x00,
    E2E_P11STATUS_NONEWDATA = 0x01,
    E2E_P11STATUS_ERROR = 0x07,
    E2E_P11STATUS_REPEATED = 0x08,
    E2E_P11STATUS_OKSOMELOST = 0x20,
    E2E_P11STATUS_WRONGSEQUENCE = 0x40,
    E2E_P11STATUS_TIMEOUT = 0x50
} E2E_P11CheckStatusType;

typedef struct {
    E2E_P11CheckStatusType Status;
    uint8 Counter;
} E2E_P11CheckStateType;

/* ----------------------------------------- Type definitions for Profile 22 ---------------------------------------- */
typedef struct {
    uint16 DataLength;
    uint8 DataIDList[E2E_DATAIDLIST_LENGTH];
    uint8 MaxDeltaCounter;
    uint16 Offset;
    boolean EnableCRC;
    boolean EnableCRCHW;
} E2E_P22ConfigType;

typedef  E2E_PXXProtectStateType_8bits E2E_P22ProtectStateType;

typedef enum {
    E2E_P22STATUS_OK = 0x00,
    E2E_P22STATUS_NONEWDATA = 0x01,
    E2E_P22STATUS_ERROR = 0x07,
    E2E_P22STATUS_REPEATED = 0x08,
    E2E_P22STATUS_OKSOMELOST = 0x20,
    E2E_P22STATUS_WRONGSEQUENCE = 0x40,
    E2E_P22STATUS_TIMEOUT = 0x50
} E2E_P22CheckStatusType;

typedef struct {
    uint8 Counter;
    E2E_P22CheckStatusType Status;
} E2E_P22CheckStateType;

/* --------------------------------------- Type definitions for State Machine --------------------------------------- */
#ifdef ENABLE_E2E_P04_EXERRCODE
typedef enum {
    E2E_P_OK = 0x00,
    E2E_P_REPEATED = 0x01,
    E2E_P_WRONGSEQUENCE = 0x02,
    E2E_P_ERROR = 0x03,
    E2E_P_CRCERROR = 0x03,
    E2E_P_NOTAVAILABLE = 0x04,
    E2E_P_NONEWDATA = 0x05,
    E2E_P_TIMEOUT = 0x06,
    E2E_P_DIDERROR = 0x0A,
    E2E_P_DLENERROR = 0x0B,
} E2E_PCheckStatusType;
#else
typedef enum {
    E2E_P_OK = 0x00,
    E2E_P_REPEATED = 0x01,
    E2E_P_WRONGSEQUENCE = 0x02,
    E2E_P_ERROR = 0x03,
    E2E_P_NOTAVAILABLE = 0x04,
    E2E_P_NONEWDATA = 0x05,
    E2E_P_TIMEOUT = 0x06
} E2E_PCheckStatusType;
#endif

typedef enum {
    E2E_SM_VALID = 0x00U,
    E2E_SM_DEINIT = 0x01U,
    E2E_SM_NODATA = 0x02U,
    E2E_SM_INIT = 0x03U,
    E2E_SM_INVALID = 0x04U,
    E2E_SM_INVALID_PERMANENT = 0x05U,
} E2E_SMStateType;

typedef struct {
    uint8* ProfileStatusWindow;
    uint8  WindowTopIndex;
    uint8  OkCount;
    uint8  ErrorCount;
    E2E_SMStateType SMState;
} E2E_SMCheckStateType;

#ifdef ENABLE_PRE_1911
typedef struct {
    uint8 WindowSize;
    uint8 MinOkStateInit;
    uint8 MaxErrorStateInit;
    uint8 MinOkStateValid;
    uint8 MaxErrorStateValid;
    uint8 MinOkStateInvalid;
    uint8 MaxErrorStateInvalid;
} E2E_SMConfigType;
#else
typedef struct {
    uint8 WindowSizeValid;
    uint8 MinOkStateInit;
    uint8 MaxErrorStateInit;
    uint8 MinOkStateValid;
    uint8 MaxErrorStateValid;
    uint8 MinOkStateInvalid;
    uint8 MaxErrorStateInvalid;
    uint8 WindowSizeInit;
    uint8 WindowSizeInvalid;
    boolean ClearToInvalid;
} E2E_SMConfigType;
#endif

#ifdef ENABLE_VERSION_INFO
/**
 * @brief The function for get version info for Classic AutoSAR.
 * @param[in]  Versioninfo        Pointer to where to store the version information of this module.
 */
FUNC(void, E2E_CODE) E2E_GetVersionInfo(P2VAR(Std_VersionInfoType, AUTOMATIC, E2E_APPL_DATA) Versioninfo);
#endif

#define E2E_LOCAL static

#ifdef __cplusplus
}
#endif

#ifdef ENABLE_MEMMAP
#define E2E_STOP_SEC_CODE
#include "E2E_MemMap.h"
#endif

#endif

