/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.
 * Description: The header file of E2E_SM.c including all definitions in E2E_SM.c
 * Create: 2019-06-17
 */

#ifndef E2E_SM_H
#define E2E_SM_H

#include "Std_Types.h"
#include "E2E.h"

#ifdef ENABLE_STD_TYPES
#include "Std_Macro.h"
#endif

#ifdef ENABLE_MEMMAP
#define E2E_START_SEC_CODE
#include "E2E_MemMap.h"
#endif
/**
 * @file
 *
 * @brief The header file of E2E_SM.c including all definitions in E2E_SM.c
 */
/**
* @brief Add the single check result to the state of state Machile
 *
 * @req{ SAR-VOS-E2E-SM-00001
 * VOS E2E-General shall report if the data can be used for safety-related aplication; based on history of checks,
 * D,
 * SDR-VOS-E2E-00011,
 * }
 *
 * @req{ AR-iAOS-E2E-SM-00001,
 * E2E-SM shall report if the data can be used for safety-related aplication, based on history of checks,
 * D,
 * DR-iAOS-RTF-RTFE2E-00019,
 * }
 *
* @param[in] ProfileStatus     Profile-independent status of the reception on one single Data in one cycle
* @param[inout] StatePtr      Pointer to port/data communication state
* @param[in] ConfigPtr     Pointer to static configuration
* @retval E2E_E_INTERR             An internal library error has occurred
* @retval E2E_E_OK                 Function completed successfully
*/
FUNC(Std_ReturnType, E2E_CODE) E2E_SMCheck(VAR(E2E_PCheckStatusType, AUTOMATIC) ProfileStatus,
                                           P2CONST(E2E_SMConfigType, AUTOMATIC, E2E_APPL_DATA) ConfigPtr,
                                           P2VAR(E2E_SMCheckStateType, AUTOMATIC, E2E_APPL_DATA) StatePtr);

/**
* @brief Initializes the state machine
 *
 * @req{ SAR-VOS-E2E-SM-00002
 * VOS E2E-General shall provide a function to initialize the state machine,
 * D,
 * SDR-VOS-E2E-00011,
 * }
 *
 * @req{ AR-iAOS-E2E-SM-00002,
 * E2E-SM shall provide a function to initialize the state machine,
 * D,
 * DR-iAOS-RTF-RTFE2E-00019,
 * }
 *
* @param[in] StatePtr      Pointer to port/data communication state
* @param[in] ConfigPtr     Pointer to configuration of the state machine
* @retval E2E_E_INPUTERR_NULL      At least one pointer parameter is a NULL pointer
* @retval E2E_E_OK                 Function completed successfully
*/
FUNC(Std_ReturnType, E2E_CODE) E2E_SMCheckInit(P2VAR(E2E_SMCheckStateType, AUTOMATIC, E2E_APPL_DATA) StatePtr,
                                               P2CONST(E2E_SMConfigType, AUTOMATIC, E2E_APPL_DATA) ConfigPtr);

#ifdef ENABLE_MEMMAP
#define E2E_STOP_SEC_CODE
#include "E2E_MemMap.h"
#endif

#endif
