/**************************************************************************************
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2023. All rights reserved.
 * Description: Rte_Endianess.h
 * Author: VOS OS
 * Create: 2019-12-31
 *
 **************************************************************************************/
#ifndef RTE_ENDIANESS_H
#define RTE_ENDIANESS_H

#define RTE_ENDIANESS_AR_RELEASE_MAJOR_VERSION 4U
#define RTE_ENDIANESS_AR_RELEASE_MINOR_VERSION 4U

/********************************************************************
 *
 *       Bit ordering
 *
 ********************************************************************/
#if (defined(RTE_ENDIANESS_BITSWAP) && (RTE_ENDIANESS_BITSWAP == STD_ON))

/* Swap bits in a byte.  */
#define rte_bitswap_8(x) \
    ((uint8) ((((x) & 0x01u) << 7)              \
            | (((x) & 0x02u) << 5)              \
            | (((x) & 0x04u) << 3)              \
            | (((x) & 0x08u) << 1)              \
            | (((x) & 0x10u) >> 1)              \
            | (((x) & 0x20u) >> 3)              \
            | (((x) & 0x40u) >> 5)              \
            | (((x) & 0x80u) >> 7)))

/* Swap bits in a 2bytes.  */
#define rte_bitswap_16(x) \
    ((uint16) ((((x) & 0x0101u) << 7)             \
            | (((x) & 0x0202u) << 5)              \
            | (((x) & 0x0404u) << 3)              \
            | (((x) & 0x0808u) << 1)              \
            | (((x) & 0x1010u) >> 1)              \
            | (((x) & 0x2020u) >> 3)              \
            | (((x) & 0x4040u) >> 5)              \
            | (((x) & 0x8080u) >> 7)))

/* Swap bits in a 4bytes.  */
#define rte_bitswap_32(x) \
    ((uint32) ((((x) & 0x01010101UL) << 7)             \
            | (((x) & 0x02020202UL) << 5)              \
            | (((x) & 0x04040404UL) << 3)              \
            | (((x) & 0x08080808UL) << 1)              \
            | (((x) & 0x10101010UL) >> 1)              \
            | (((x) & 0x20202020UL) >> 3)              \
            | (((x) & 0x40404040UL) >> 5)              \
            | (((x) & 0x80808080UL) >> 7)))

/* Swap bits in a 8bytes.  */
#define rte_bitswap_64(x) \
    ((uint64) ((((x) & 0x0101010101010101ULL) << 7)             \
            | (((x) & 0x0202020202020202ULL) << 5)              \
            | (((x) & 0x0404040404040404ULL) << 3)              \
            | (((x) & 0x0808080808080808ULL) << 1)              \
            | (((x) & 0x1010101010101010ULL) >> 1)              \
            | (((x) & 0x2020202020202020ULL) >> 3)              \
            | (((x) & 0x4040404040404040ULL) >> 5)              \
            | (((x) & 0x8080808080808080ULL) >> 7)))

#else

/* Disable Swap bits. (it looks like no one swaps bits)  */
#define rte_bitswap_8(x)  (x)
#define rte_bitswap_16(x) (x)
#define rte_bitswap_32(x) (x)
#define rte_bitswap_64(x) (x)

#endif

#if CPU_BIT_ORDER == LSB_FIRST
/**
 *
 *       Locally BIT ordering is Little Endian
 *
 **/
#define rte_to_lsbit_first8(x)  (x)
#define rte_to_lsbit_first16(x) (x)
#define rte_to_lsbit_first32(x) (x)
#define rte_to_lsbit_first64(x) (x)

#define rte_to_msbit_first8(x)  rte_bitswap_8(x)
#define rte_to_msbit_first16(x) rte_bitswap_16(x)
#define rte_to_msbit_first32(x) rte_bitswap_32(x)
#define rte_to_msbit_first64(x) rte_bitswap_64(x)

#elif CPU_BIT_ORDER == MSB_FIRST
/**
 *
 *       Locally BIT ordering is Big Endian
 *
 **/
#define rte_to_lsbit_first8(x)  rte_bitswap_8(x)
#define rte_to_lsbit_first16(x) rte_bitswap_16(x)
#define rte_to_lsbit_first32(x) rte_bitswap_32(x)
#define rte_to_lsbit_first64(x) rte_bitswap_64(x)

#define rte_to_msbit_first8(x)  (x)
#define rte_to_msbit_first16(x) (x)
#define rte_to_msbit_first32(x) (x)
#define rte_to_msbit_first64(x) (x)

#else
/**
 *
 *       Error
 *
 **/
#error "Invalid bit ordering"

#endif

/********************************************************************
 *
 *       BYTE ordering
 *
 *
 *       uint16 value = 0x0123
 *
 *       Little endian             Big endian
 *        +----+----+              +----+----+
 *        |0x23|0x01|              |0x01|0x23|
 *        +----+----+              +----+----+
 *  byte:    0    1                   0    1
 *
 *
 *      byte 0 =  ((val)        & 0xff)
 *      byte 1 = (((val) >> 8)  & 0xff)
 *
 ********************************************************************/
/* Store bytes in a byte array buffer (directly or with byte swap)
 *   val  is the value to store
 *   buff is the pointer to the first free byte of the buffer
 */
/*             8bit -----> buffer  */
#define rte_byte_to_buff_8(val, buff) \
    (((uint8*) (buff))[0U] = (uint8)  (((const uint8) (val))        & 0xffU))

#define rte_byteswap_to_buff_8(val, buff) \
    (((uint8*) (buff))[0U] = (uint8)  (((const uint8) (val))        & 0xffU))

/*            16bit -----> buffer  */
#define rte_byte_to_buff_16(val, buff) \
    (((uint8*) (buff))[0U] = (uint8)  (((const uint16) (val))        & 0xffU),     \
        ((uint8*) (buff))[1U] = (uint8) ((((const uint16) (val)) >> 8U)  & 0xffU)       \
    )

#define rte_byteswap_to_buff_16(val, buff) \
    (((uint8*) (buff))[0U] = (uint8) ((((const uint16) (val)) >> 8U)  & 0xffU),     \
        ((uint8*) (buff))[1U] = (uint8)  (((const uint16) (val))        & 0xffU)       \
    )

/*            32bit -----> buffer  */
#define rte_byte_to_buff_32(val, buff) \
    (((uint8*) (buff))[0U] = (uint8)  ((*((const uint32*) &(val)))        & 0xffU),    \
        ((uint8*) (buff))[1U] = (uint8) (((*((const uint32*) &(val))) >> 8U)  & 0xffU),    \
        ((uint8*) (buff))[2U] = (uint8) (((*((const uint32*) &(val))) >> 16U) & 0xffU),    \
        ((uint8*) (buff))[3U] = (uint8) (((*((const uint32*) &(val))) >> 24U) & 0xffU)      \
    )

#define rte_byteswap_to_buff_32(val, buff) \
    (((uint8*) (buff))[0U] = (uint8) (((*((const uint32*) &(val))) >> 24U) & 0xffU),    \
        ((uint8*) (buff))[1U] = (uint8) (((*((const uint32*) &(val))) >> 16U) & 0xffU),    \
        ((uint8*) (buff))[2U] = (uint8) (((*((const uint32*) &(val))) >> 8U)  & 0xffU),    \
        ((uint8*) (buff))[3U] = (uint8)  ((*((const uint32*) &(val)))        & 0xffU)      \
    )

/*            64bit -----> buffer  */
#define rte_byte_to_buff_64(val, buff) \
    (((uint8*) (buff))[0U] = (uint8)  ((*((const uint64*) &(val)))        & 0xffU),    \
        ((uint8*) (buff))[1U] = (uint8) (((*((const uint64*) &(val))) >> 8U)  & 0xffU),    \
        ((uint8*) (buff))[2U] = (uint8) (((*((const uint64*) &(val))) >> 16U) & 0xffU),    \
        ((uint8*) (buff))[3U] = (uint8) (((*((const uint64*) &(val))) >> 24U) & 0xffU),    \
        ((uint8*) (buff))[4U] = (uint8) (((*((const uint64*) &(val))) >> 32U) & 0xffU),    \
        ((uint8*) (buff))[5U] = (uint8) (((*((const uint64*) &(val))) >> 40U) & 0xffU),    \
        ((uint8*) (buff))[6U] = (uint8) (((*((const uint64*) &(val))) >> 48U) & 0xffU),    \
        ((uint8*) (buff))[7U] = (uint8) (((*((const uint64*) &(val))) >> 56U) & 0xffU)      \
    )

#define rte_byteswap_to_buff_64(val, buff) \
    (((uint8*) (buff))[0U] = (uint8) (((*((const uint64*) &(val))) >> 56U) & 0xffU),    \
        ((uint8*) (buff))[1U] = (uint8) (((*((const uint64*) &(val))) >> 48U) & 0xffU),    \
        ((uint8*) (buff))[2U] = (uint8) (((*((const uint64*) &(val))) >> 40U) & 0xffU),    \
        ((uint8*) (buff))[3U] = (uint8) (((*((const uint64*) &(val))) >> 32U) & 0xffU),    \
        ((uint8*) (buff))[4U] = (uint8) (((*((const uint64*) &(val))) >> 24U) & 0xffU),    \
        ((uint8*) (buff))[5U] = (uint8) (((*((const uint64*) &(val))) >> 16U) & 0xffU),    \
        ((uint8*) (buff))[6U] = (uint8) (((*((const uint64*) &(val))) >> 8U)  & 0xffU),    \
        ((uint8*) (buff))[7U] = (uint8)  ((*((const uint64*) &(val)))        & 0xffU)      \
    )

/* Read bytes from a byte array buffer and rebuild a value,
 * (directly or with byte swap)
 *   buff is the pointer to the first valid byte of the buffer
 */
/*             8bit <----- buffer  */
#define rte_byte_from_buff_8(buff, val) \
    ((*((uint8*) &(val))) = ((const uint8) (((const uint8 * const) (buff))[0U])))
#define rte_byteswap_from_buff_8(buff, val) \
    ((*((uint8*) &(val))) = ((const uint8) (((const uint8 * const) (buff))[0U])))

/*            16bit <----- buffer  */
#define rte_byte_from_buff_16(buff, val) \
    ((*((uint16*) &(val))) = (uint16) \
        ((uint16) (((const uint8*) (buff))[0U]))         \
        | (((uint16) (((const uint8*) (buff))[1U])) <<  8U)  \
    )

#define rte_byteswap_from_buff_16(buff, val) \
    ((*((uint16*) &(val))) = (uint16) \
        (((uint16) (((const uint8*) (buff))[0U])) <<  8U)  \
        |   ((uint16) (((const uint8*) (buff))[1U]))         \
    )

/*            32bit <----- buffer  */
#define rte_byte_from_buff_32(buff, val) \
    ((*((uint32*) &(val))) = (uint32) \
        ((uint32) (((const uint8*) (buff))[0U]))         \
        | (((uint32) (((const uint8*) (buff))[1U])) <<  8U)  \
        | (((uint32) (((const uint8*) (buff))[2U])) << 16U)  \
        | (((uint32) (((const uint8*) (buff))[3U])) << 24U)  \
    )

#define rte_byteswap_from_buff_32(buff, val) \
    ((*((uint32*) &(val))) = (uint32) \
        (((uint32) (((const uint8*) (buff))[0U])) << 24U)  \
        | (((uint32) (((const uint8*) (buff))[1U])) << 16U)  \
        | (((uint32) (((const uint8*) (buff))[2U])) <<  8U)  \
        | ((uint32) (((const uint8*) (buff))[3U]))         \
    )

/*            64bit <----- buffer  */
# define rte_byte_from_buff_64(buff, val) \
    ((*((uint64*) &(val))) = (uint64) \
        ((uint64) (((const uint8*) (buff))[0U]))         \
        | (((uint64) (((const uint8*) (buff))[1U])) <<  8U)  \
        | (((uint64) (((const uint8*) (buff))[2U])) << 16U)  \
        | (((uint64) (((const uint8*) (buff))[3U])) << 24U)  \
        | (((uint64) (((const uint8*) (buff))[4U])) << 32U)  \
        | (((uint64) (((const uint8*) (buff))[5U])) << 40U)  \
        | (((uint64) (((const uint8*) (buff))[6U])) << 48U)  \
        | (((uint64) (((const uint8*) (buff))[7U])) << 56U)  \
    )

# define rte_byteswap_from_buff_64(buff, val) \
    ((*((uint64*) &(val))) = (uint64) \
        (((uint64) (((const uint8*) (buff))[0U])) << 56U)  \
        | (((uint64) (((const uint8*) (buff))[1U])) << 48U)  \
        | (((uint64) (((const uint8*) (buff))[2U])) << 40U)  \
        | (((uint64) (((const uint8*) (buff))[3U])) << 32U)  \
        | (((uint64) (((const uint8*) (buff))[4U])) << 24U)  \
        | (((uint64) (((const uint8*) (buff))[5U])) << 16U)  \
        | (((uint64) (((const uint8*) (buff))[6U])) <<  8U)  \
        | ((uint64) (((const uint8*) (buff))[7U]))         \
    )

#if CPU_BYTE_ORDER == LOW_BYTE_FIRST

/**
 *
 *       Locally BYTE ordering is Little Endian
 *
 **/
// ---------------->  TO Buffer
/********** 1 Byte **********/
#define rte_8bit_to_lowbyte_lessbit(val, buff)   rte_byte_to_buff_8     (rte_to_lsbit_first8 (val), buff)
#define rte_8bit_to_lowbyte_mostbit(val, buff)   rte_byte_to_buff_8     (rte_to_msbit_first8 (val), buff)
#define rte_8bit_to_highbyte_lessbit(val, buff)  rte_byteswap_to_buff_8 (rte_to_lsbit_first8 (val), buff)
#define rte_8bit_to_highbyte_mostbit(val, buff)  rte_byteswap_to_buff_8 (rte_to_msbit_first8 (val), buff)

/********** 2 Byte **********/
#define rte_16bit_to_lowbyte_lessbit(val, buff)  rte_byte_to_buff_16    (rte_to_lsbit_first16(val), buff)
#define rte_16bit_to_lowbyte_mostbit(val, buff)  rte_byte_to_buff_16    (rte_to_msbit_first16(val), buff)
#define rte_16bit_to_highbyte_lessbit(val, buff) rte_byteswap_to_buff_16(rte_to_lsbit_first16(val), buff)
#define rte_16bit_to_highbyte_mostbit(val, buff) rte_byteswap_to_buff_16(rte_to_msbit_first16(val), buff)

/********** 4 Byte **********/
#define rte_32bit_to_lowbyte_lessbit(val, buff)  rte_byte_to_buff_32    (rte_to_lsbit_first32(val), buff)
#define rte_32bit_to_lowbyte_mostbit(val, buff)  rte_byte_to_buff_32    (rte_to_msbit_first32(val), buff)
#define rte_32bit_to_highbyte_lessbit(val, buff) rte_byteswap_to_buff_32(rte_to_lsbit_first32(val), buff)
#define rte_32bit_to_highbyte_mostbit(val, buff) rte_byteswap_to_buff_32(rte_to_msbit_first32(val), buff)

/********** 8 Byte **********/
#define rte_64bit_to_lowbyte_lessbit(val, buff)  rte_byte_to_buff_64    (rte_to_lsbit_first64(val), buff)
#define rte_64bit_to_lowbyte_mostbit(val, buff)  rte_byte_to_buff_64    (rte_to_msbit_first64(val), buff)
#define rte_64bit_to_highbyte_lessbit(val, buff) rte_byteswap_to_buff_64(rte_to_lsbit_first64(val), buff)
#define rte_64bit_to_highbyte_mostbit(val, buff) rte_byteswap_to_buff_64(rte_to_msbit_first64(val), buff)

//                 FROM Buffer  <--------------------
/********** 1 Byte **********/
#define rte_8bit_from_lowbyte_lessbit(buff, val)   rte_to_lsbit_first8 (rte_byte_from_buff_8     (buff, val))
#define rte_8bit_from_lowbyte_mostbit(buff, val)   rte_to_msbit_first8 (rte_byte_from_buff_8     (buff, val))
#define rte_8bit_from_highbyte_lessbit(buff, val)  rte_to_lsbit_first8 (rte_byteswap_from_buff_8 (buff, val))
#define rte_8bit_from_highbyte_mostbit(buff, val)  rte_to_msbit_first8 (rte_byteswap_from_buff_8 (buff, val))

/********** 2 Byte **********/
#define rte_16bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first16(rte_byte_from_buff_16    (buff, val))
#define rte_16bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first16(rte_byte_from_buff_16    (buff, val))
#define rte_16bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first16(rte_byteswap_from_buff_16(buff, val))
#define rte_16bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first16(rte_byteswap_from_buff_16(buff, val))

/********** 4 Byte **********/
#define rte_32bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first32(rte_byte_from_buff_32    (buff, val))
#define rte_32bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first32(rte_byte_from_buff_32    (buff, val))
#define rte_32bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first32(rte_byteswap_from_buff_32(buff, val))
#define rte_32bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first32(rte_byteswap_from_buff_32(buff, val))

/********** 8 Byte **********/
#define rte_64bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first64(rte_byte_from_buff_64    (buff, val))
#define rte_64bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first64(rte_byte_from_buff_64    (buff, val))
#define rte_64bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first64(rte_byteswap_from_buff_64(buff, val))
#define rte_64bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first64(rte_byteswap_from_buff_64(buff, val))

#elif CPU_BYTE_ORDER == HIGH_BYTE_FIRST
/**
 *
 *       Locally BYTE ordering is Big Endian
 *
 **/
// ---------------->  TO Buffer
/********** 1 Byte **********/
#define rte_8bit_to_lowbyte_lessbit(val, buff)   rte_byteswap_to_buff_8 (rte_to_lsbit_first8 (val), buff)
#define rte_8bit_to_lowbyte_mostbit(val, buff)   rte_byteswap_to_buff_8 (rte_to_msbit_first8 (val), buff)
#define rte_8bit_to_highbyte_lessbit(val, buff)  rte_byte_to_buff_8     (rte_to_lsbit_first8 (val), buff)
#define rte_8bit_to_highbyte_mostbit(val, buff)  rte_byte_to_buff_8     (rte_to_msbit_first8 (val), buff)

/********** 2 Byte **********/
#define rte_16bit_to_lowbyte_lessbit(val, buff)  rte_byteswap_to_buff_16(rte_to_lsbit_first16(val), buff)
#define rte_16bit_to_lowbyte_mostbit(val, buff)  rte_byteswap_to_buff_16(rte_to_msbit_first16(val), buff)
#define rte_16bit_to_highbyte_lessbit(val, buff) rte_byte_to_buff_16    (rte_to_lsbit_first16(val), buff)
#define rte_16bit_to_highbyte_mostbit(val, buff) rte_byte_to_buff_16    (rte_to_msbit_first16(val), buff)

/********** 4 Byte **********/
#define rte_32bit_to_lowbyte_lessbit(val, buff)  rte_byteswap_to_buff_32(rte_to_lsbit_first32(val), buff)
#define rte_32bit_to_lowbyte_mostbit(val, buff)  rte_byteswap_to_buff_32(rte_to_msbit_first32(val), buff)
#define rte_32bit_to_highbyte_lessbit(val, buff) rte_byte_to_buff_32    (rte_to_lsbit_first32(val), buff)
#define rte_32bit_to_highbyte_mostbit(val, buff) rte_byte_to_buff_32    (rte_to_msbit_first32(val), buff)

/********** 8 Byte **********/
#define rte_64bit_to_lowbyte_lessbit(val, buff)  rte_byteswap_to_buff_64(rte_to_lsbit_first64(val), buff)
#define rte_64bit_to_lowbyte_mostbit(val, buff)  rte_byteswap_to_buff_64(rte_to_msbit_first64(val), buff)
#define rte_64bit_to_highbyte_lessbit(val, buff) rte_byte_to_buff_64    (rte_to_lsbit_first64(val), buff)
#define rte_64bit_to_highbyte_mostbit(val, buff) rte_byte_to_buff_64    (rte_to_msbit_first64(val), buff)

//                 FROM Buffer  <--------------------
/********** 1 Byte **********/
#define rte_8bit_from_lowbyte_lessbit(buff, val)   rte_to_lsbit_first8 (rte_byteswap_from_buff_8 (buff, val))
#define rte_8bit_from_lowbyte_mostbit(buff, val)   rte_to_msbit_first8 (rte_byteswap_from_buff_8 (buff, val))
#define rte_8bit_from_highbyte_lessbit(buff, val)  rte_to_lsbit_first8 (rte_byte_from_buff_8     (buff, val))
#define rte_8bit_from_highbyte_mostbit(buff, val)  rte_to_msbit_first8 (rte_byte_from_buff_8     (buff, val))

/********** 2 Byte **********/
#define rte_16bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first16(rte_byteswap_from_buff_16(buff, val))
#define rte_16bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first16(rte_byteswap_from_buff_16(buff, val))
#define rte_16bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first16(rte_byte_from_buff_16    (buff, val))
#define rte_16bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first16(rte_byte_from_buff_16    (buff, val))

/********** 4 Byte **********/
#define rte_32bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first32(rte_byteswap_from_buff_32(buff, val))
#define rte_32bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first32(rte_byteswap_from_buff_32(buff, val))
#define rte_32bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first32(rte_byte_from_buff_32    (buff, val))
#define rte_32bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first32(rte_byte_from_buff_32    (buff, val))

/********** 8 Byte **********/
#define rte_64bit_from_lowbyte_lessbit(buff, val)  rte_to_lsbit_first64(rte_byteswap_from_buff_64(buff, val))
#define rte_64bit_from_lowbyte_mostbit(buff, val)  rte_to_msbit_first64(rte_byteswap_from_buff_64(buff, val))
#define rte_64bit_from_highbyte_lessbit(buff, val) rte_to_lsbit_first64(rte_byte_from_buff_64    (buff, val))
#define rte_64bit_from_highbyte_mostbit(buff, val) rte_to_msbit_first64(rte_byte_from_buff_64    (buff, val))

#else
/**
 *
 *       Error
 *
 **/
#error "Invalid byte ordering"

#endif

/********** Conversions from/to SomeIP **********/
#define rte_to_someIp_8bit(val, buff)  rte_8bit_to_highbyte_mostbit (val, buff)
#define rte_to_someIp_16bit(val, buff) rte_16bit_to_highbyte_mostbit(val, buff)
#define rte_to_someIp_32bit(val, buff) rte_32bit_to_highbyte_mostbit(val, buff)
#define rte_to_someIp_64bit(val, buff) rte_64bit_to_highbyte_mostbit(val, buff)

#define rte_from_someIp_8bit(buff, val)  rte_8bit_from_highbyte_mostbit (buff, val)
#define rte_from_someIp_16bit(buff, val) rte_16bit_from_highbyte_mostbit(buff, val)
#define rte_from_someIp_32bit(buff, val) rte_32bit_from_highbyte_mostbit(buff, val)
#define rte_from_someIp_64bit(buff, val) rte_64bit_from_highbyte_mostbit(buff, val)

#endif /* RTE_ENDIANESS_H */