/**************************************************************************************
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2023. All rights reserved.
 * Description: Rte_Proxy.h
 * Author: VOS OS
 * Create: 2019-12-31
 *
 **************************************************************************************/
#ifndef RTE_PROXY_H
#define RTE_PROXY_H

/*
 * queue type
 *
 * elementArrayPtr: queue corresponds the first address of situation array
 * front: header index(index in elementArray)
 * stat: queue state
 * elementCount: count of queue elements
 * elementArraySize: length of queue, size of elementArray
 * elementSize: bytes of each element in elementArray
 */
#if !defined(RTE_TYPE_RteQueueSizeType)
#define RTE_TYPE_RteQueueSizeType
typedef uint32 RteQueueSizeType;
typedef uint32 RteQueueElementSizeType32;
typedef uint8 ByteType8;
#endif

typedef unsigned long dataLengthType;

typedef struct {
    P2VAR(void, AUTOMATIC, RTE_CODE) elementArrayPtr;
    VAR(RteQueueSizeType, AUTOMATIC) front;
    VAR(Std_ReturnType, AUTOMATIC) stat;
    VAR(RteQueueSizeType, AUTOMATIC) elementCount;
    VAR(RteQueueSizeType, AUTOMATIC) elementArraySize;
    VAR(RteQueueElementSizeType32, AUTOMATIC) elementSize;
} RteQueueType;

typedef struct {
    VAR(uint32, AUTOMATIC) saveIndex;
    VAR(uint32, AUTOMATIC) thisIndex;
    VAR(uint32, AUTOMATIC) elementSize;
} RteCacheDataSendInfo;

typedef struct {
    P2VAR(uint8, AUTOMATIC, AUTOSAR_COMSTACKDATA) dataPtr;
    P2VAR(uint8, AUTOMATIC, RTE_APPL_DATA) MetaDataPtr;
} str_rte_proxy_buff_data;

typedef struct {
    P2VAR(RteQueueType, AUTOMATIC, RTE_APPL_DATA) buffer_data;
    P2VAR(uint8, AUTOMATIC, RTE_APPL_DATA) saveNoQueueBufferData;
    P2VAR(boolean, AUTOMATIC, RTE_APPL_DATA) tpTransLock;
    VAR(uint16, AUTOMATIC) pdu_id;
    VAR(boolean, AUTOMATIC) ldComTxCallBackSendLock;
    VAR(boolean, AUTOMATIC) ldComTxStatus;
    VAR(boolean, AUTOMATIC) isUseTPFlag;
    VAR(uint8, AUTOMATIC) return_of_LdComTransmit;
    VAR(PduInfoType, AUTOMATIC) pdu_info;
    VAR(boolean, AUTOMATIC) isUpdated;
    VAR(boolean, AUTOMATIC) isBufferDataUpdate;
    VAR(boolean, AUTOMATIC) isLdComProxyDataQueued;
    P2VAR(uint8, AUTOMATIC, RTE_APPL_DATA) MetaDataPtr;
    VAR(dataLengthType, AUTOMATIC) MetaDataLength;
} str_rte_proxy_buff;

/***************************************************************************
 *
 * LdCom Period Proxy Var
 *
 **************************************************************************/
#define ECUCPARTITION_C1_APP_QM_LDCOMPERIODPROXYTX_SIZE 59U
/***************************************************************************
 *
 * Define ISignal LdComIPdu macros
 *
 **************************************************************************/
/* SIG_Event_ImuAbstractMcuToSoc_SaBoardImuAbstract */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_IMUABSTRACTMCUTOSOC_SABOARDIMUABSTRACT)
#define RTE_LDCOM_SIGIPDU_EVENT_IMUABSTRACTMCUTOSOC_SABOARDIMUABSTRACT 0U
#endif
/* SIG_Event_IntfMcuSendEdrDataToSoc_Service_Intf_Edr */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_INTFMCUSENDEDRDATATOSOC_SERVICE_INTF_EDR)
#define RTE_LDCOM_SIGIPDU_EVENT_INTFMCUSENDEDRDATATOSOC_SERVICE_INTF_EDR 1U
#endif
/* SIG_Event_LogEvent_Service_Log */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_LOGEVENT_SERVICE_LOG)
#define RTE_LDCOM_SIGIPDU_EVENT_LOGEVENT_SERVICE_LOG 2U
#endif
/* SIG_Event_NotifyPlatStateToHost_SmHeartBeatSnd */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_NOTIFYPLATSTATETOHOST_SMHEARTBEATSND)
#define RTE_LDCOM_SIGIPDU_EVENT_NOTIFYPLATSTATETOHOST_SMHEARTBEATSND 3U
#endif
/* SIG_Event_NotifyPlatStateToHost_SmSsServerHeartBeat */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_NOTIFYPLATSTATETOHOST_SMSSSERVERHEARTBEAT)
#define RTE_LDCOM_SIGIPDU_EVENT_NOTIFYPLATSTATETOHOST_SMSSSERVERHEARTBEAT 4U
#endif
/* SIG_Event_SM_HeartbeatSnd_SmHeartBeatSnd */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_SM_HEARTBEATSND_SMHEARTBEATSND)
#define RTE_LDCOM_SIGIPDU_EVENT_SM_HEARTBEATSND_SMHEARTBEATSND 5U
#endif
/* SIG_Event_SM_SsHeartbeatSnd_SmSsServerHeartBeat */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_SM_SSHEARTBEATSND_SMSSSERVERHEARTBEAT)
#define RTE_LDCOM_SIGIPDU_EVENT_SM_SSHEARTBEATSND_SMSSSERVERHEARTBEAT 6U
#endif
/* SIG_Event_SomeipTsyncSendGpsPpsTime_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_SOMEIPTSYNCSENDGPSPPSTIME_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_EVENT_SOMEIPTSYNCSENDGPSPPSTIME_SERVICE_TIMESYNC 7U
#endif
/* SIG_Event_SomeipTsyncSendUtcTime_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_SOMEIPTSYNCSENDUTCTIME_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_EVENT_SOMEIPTSYNCSENDUTCTIME_SERVICE_TIMESYNC 8U
#endif
/* SIG_Event_WorkModeNotify_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_EVENT_WORKMODENOTIFY_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_EVENT_WORKMODENOTIFY_SMSERVICE 9U
#endif
/* SIG_RR_CanNmCtrl_return_Cis_ECU1_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_CANNMCTRL_RETURN_CIS_ECU1_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_CANNMCTRL_RETURN_CIS_ECU1_SMSERVICE 10U
#endif
/* SIG_RR_CheckMcuVersion_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_CHECKMCUVERSION_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_CHECKMCUVERSION_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 11U
#endif
/* SIG_RR_CtrlMcuPower_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_CTRLMCUPOWER_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_CTRLMCUPOWER_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 12U
#endif
/* SIG_RR_DcComCtrlCanChnlConfig_return_Cis_ECU1_DcComCtrlServer */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DCCOMCTRLCANCHNLCONFIG_RETURN_CIS_ECU1_DCCOMCTRLSERVER)
#define RTE_LDCOM_SIGIPDU_RR_DCCOMCTRLCANCHNLCONFIG_RETURN_CIS_ECU1_DCCOMCTRLSERVER 13U
#endif
/* SIG_RR_DevmReadConfig_return_Cis_ECU1_Service_CfgManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DEVMREADCONFIG_RETURN_CIS_ECU1_SERVICE_CFGMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_DEVMREADCONFIG_RETURN_CIS_ECU1_SERVICE_CFGMANAGE 14U
#endif
/* SIG_RR_DevmReadUartData_return_Cis_ECU1_Service_CfgManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DEVMREADUARTDATA_RETURN_CIS_ECU1_SERVICE_CFGMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_DEVMREADUARTDATA_RETURN_CIS_ECU1_SERVICE_CFGMANAGE 15U
#endif
/* SIG_RR_DevmdGetInfomation_return_Cis_ECU1_Service_CfgManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DEVMDGETINFOMATION_RETURN_CIS_ECU1_SERVICE_CFGMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_DEVMDGETINFOMATION_RETURN_CIS_ECU1_SERVICE_CFGMANAGE 16U
#endif
/* SIG_RR_DiagReadDid_return_Cis_ECU1_Service_DiagnoseWrDid */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DIAGREADDID_RETURN_CIS_ECU1_SERVICE_DIAGNOSEWRDID)
#define RTE_LDCOM_SIGIPDU_RR_DIAGREADDID_RETURN_CIS_ECU1_SERVICE_DIAGNOSEWRDID 17U
#endif
/* SIG_RR_DiagWriteDid_return_Cis_ECU1_Service_DiagnoseWrDid */
#if !defined(RTE_LDCOM_SIGIPDU_RR_DIAGWRITEDID_RETURN_CIS_ECU1_SERVICE_DIAGNOSEWRDID)
#define RTE_LDCOM_SIGIPDU_RR_DIAGWRITEDID_RETURN_CIS_ECU1_SERVICE_DIAGNOSEWRDID 18U
#endif
/* SIG_RR_FmFaultReport_call_Cis_MCU_FmServer */
#if !defined(RTE_LDCOM_SIGIPDU_RR_FMFAULTREPORT_CALL_CIS_MCU_FMSERVER)
#define RTE_LDCOM_SIGIPDU_RR_FMFAULTREPORT_CALL_CIS_MCU_FMSERVER 19U
#endif
/* SIG_RR_FmGetFaultFromHost_return_Cis_ECU1_FmServerService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_FMGETFAULTFROMHOST_RETURN_CIS_ECU1_FMSERVERSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_FMGETFAULTFROMHOST_RETURN_CIS_ECU1_FMSERVERSERVICE 20U
#endif
/* SIG_RR_FmReportInfo_call_Cis_MCU_FmReportService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_FMREPORTINFO_CALL_CIS_MCU_FMREPORTSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_FMREPORTINFO_CALL_CIS_MCU_FMREPORTSERVICE 21U
#endif
/* SIG_RR_GetDevInfo_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETDEVINFO_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_GETDEVINFO_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 22U
#endif
/* SIG_RR_GetMcuAliveState_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETMCUALIVESTATE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_GETMCUALIVESTATE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 23U
#endif
/* SIG_RR_GetMcuState_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETMCUSTATE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_GETMCUSTATE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 24U
#endif
/* SIG_RR_GetPowerDownReason_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETPOWERDOWNREASON_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_GETPOWERDOWNREASON_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 25U
#endif
/* SIG_RR_GetSocStatus_return_Cis_ECU1_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETSOCSTATUS_RETURN_CIS_ECU1_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_GETSOCSTATUS_RETURN_CIS_ECU1_SMSERVICE 26U
#endif
/* SIG_RR_GetWdgAnswer_return_Cis_ECU1_ExWdgServerMethodB */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETWDGANSWER_RETURN_CIS_ECU1_EXWDGSERVERMETHODB)
#define RTE_LDCOM_SIGIPDU_RR_GETWDGANSWER_RETURN_CIS_ECU1_EXWDGSERVERMETHODB 27U
#endif
/* SIG_RR_GetWdgAnswer_return_Cis_ECU1_ExWdgServiceMethod */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETWDGANSWER_RETURN_CIS_ECU1_EXWDGSERVICEMETHOD)
#define RTE_LDCOM_SIGIPDU_RR_GETWDGANSWER_RETURN_CIS_ECU1_EXWDGSERVICEMETHOD 28U
#endif
/* SIG_RR_GetWorkMode_return_Cis_ECU1_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_GETWORKMODE_RETURN_CIS_ECU1_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_GETWORKMODE_RETURN_CIS_ECU1_SMSERVICE 29U
#endif
/* SIG_RR_MntExecCmdInfo_return_Cis_ECU1_MntDbgChannel */
#if !defined(RTE_LDCOM_SIGIPDU_RR_MNTEXECCMDINFO_RETURN_CIS_ECU1_MNTDBGCHANNEL)
#define RTE_LDCOM_SIGIPDU_RR_MNTEXECCMDINFO_RETURN_CIS_ECU1_MNTDBGCHANNEL 30U
#endif
/* SIG_RR_MntRequestCmdResult_return_Cis_ECU1_MntDbgChannel */
#if !defined(RTE_LDCOM_SIGIPDU_RR_MNTREQUESTCMDRESULT_RETURN_CIS_ECU1_MNTDBGCHANNEL)
#define RTE_LDCOM_SIGIPDU_RR_MNTREQUESTCMDRESULT_RETURN_CIS_ECU1_MNTDBGCHANNEL 31U
#endif
/* SIG_RR_NCSServiceChannel_return_Cis_ECU1_NCSServiceChannel */
#if !defined(RTE_LDCOM_SIGIPDU_RR_NCSSERVICECHANNEL_RETURN_CIS_ECU1_NCSSERVICECHANNEL)
#define RTE_LDCOM_SIGIPDU_RR_NCSSERVICECHANNEL_RETURN_CIS_ECU1_NCSSERVICECHANNEL 32U
#endif
/* SIG_RR_QuestionWdgReport_call_Cis_MCU_ExWdgClientMethod */
#if !defined(RTE_LDCOM_SIGIPDU_RR_QUESTIONWDGREPORT_CALL_CIS_MCU_EXWDGCLIENTMETHOD)
#define RTE_LDCOM_SIGIPDU_RR_QUESTIONWDGREPORT_CALL_CIS_MCU_EXWDGCLIENTMETHOD 33U
#endif
/* SIG_RR_QuestionWdgReport_call_Cis_MCU_ExWdgClientMethodB */
#if !defined(RTE_LDCOM_SIGIPDU_RR_QUESTIONWDGREPORT_CALL_CIS_MCU_EXWDGCLIENTMETHODB)
#define RTE_LDCOM_SIGIPDU_RR_QUESTIONWDGREPORT_CALL_CIS_MCU_EXWDGCLIENTMETHODB 34U
#endif
/* SIG_RR_RequestWorkModeSwitch_return_Cis_ECU1_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_REQUESTWORKMODESWITCH_RETURN_CIS_ECU1_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_REQUESTWORKMODESWITCH_RETURN_CIS_ECU1_SMSERVICE 35U
#endif
/* SIG_RR_RequestWorkMode_return_Cis_ECU1_SmService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_REQUESTWORKMODE_RETURN_CIS_ECU1_SMSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_REQUESTWORKMODE_RETURN_CIS_ECU1_SMSERVICE 36U
#endif
/* SIG_RR_SM_SsRequestState_return_Cis_ECU1_SmSsServerService */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SM_SSREQUESTSTATE_RETURN_CIS_ECU1_SMSSSERVERSERVICE)
#define RTE_LDCOM_SIGIPDU_RR_SM_SSREQUESTSTATE_RETURN_CIS_ECU1_SMSSSERVERSERVICE 37U
#endif
/* SIG_RR_SensorStateControl_return_Cis_ECU1_Service_Sam_ManagePlane */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SENSORSTATECONTROL_RETURN_CIS_ECU1_SERVICE_SAM_MANAGEPLANE)
#define RTE_LDCOM_SIGIPDU_RR_SENSORSTATECONTROL_RETURN_CIS_ECU1_SERVICE_SAM_MANAGEPLANE 38U
#endif
/* SIG_RR_SetChannelCtrl_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SETCHANNELCTRL_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_SETCHANNELCTRL_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 39U
#endif
/* SIG_RR_SetInfo_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SETINFO_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_SETINFO_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 40U
#endif
/* SIG_RR_SetPowerDownReasonRead_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SETPOWERDOWNREASONREAD_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_SETPOWERDOWNREASONREAD_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 41U
#endif
/* SIG_RR_SetSocTemperature_return_Cis_ECU1_Service_DevManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SETSOCTEMPERATURE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_SETSOCTEMPERATURE_RETURN_CIS_ECU1_SERVICE_DEVMANAGE 42U
#endif
/* SIG_RR_SomeipActive_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPACTIVE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPACTIVE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 43U
#endif
/* SIG_RR_SomeipCheckUpdateCondition_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPCHECKUPDATECONDITION_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPCHECKUPDATECONDITION_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 44U
#endif
/* SIG_RR_SomeipGetUpdateProgress_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPGETUPDATEPROGRESS_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPGETUPDATEPROGRESS_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 45U
#endif
/* SIG_RR_SomeipGetUpdateable_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPGETUPDATEABLE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPGETUPDATEABLE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 46U
#endif
/* SIG_RR_SomeipGetVersion_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPGETVERSION_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPGETVERSION_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 47U
#endif
/* SIG_RR_SomeipReboot_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPREBOOT_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPREBOOT_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 48U
#endif
/* SIG_RR_SomeipSetUpdateMode_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPSETUPDATEMODE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPSETUPDATEMODE_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 49U
#endif
/* SIG_RR_SomeipTransFinish_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFINISH_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFINISH_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 50U
#endif
/* SIG_RR_SomeipTransferData_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFERDATA_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFERDATA_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 51U
#endif
/* SIG_RR_SomeipTransferStart_return_Cis_ECU1_Service_UpgradeMcu */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFERSTART_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTRANSFERSTART_RETURN_CIS_ECU1_SERVICE_UPGRADEMCU 52U
#endif
/* SIG_RR_SomeipTsyncChEnable_return_Cis_ECU1_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCCHENABLE_RETURN_CIS_ECU1_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCCHENABLE_RETURN_CIS_ECU1_SERVICE_TIMESYNC 53U
#endif
/* SIG_RR_SomeipTsyncGetDataDelta_return_Cis_ECU1_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCGETDATADELTA_RETURN_CIS_ECU1_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCGETDATADELTA_RETURN_CIS_ECU1_SERVICE_TIMESYNC 54U
#endif
/* SIG_RR_SomeipTsyncMng_return_Cis_ECU1_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCMNG_RETURN_CIS_ECU1_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCMNG_RETURN_CIS_ECU1_SERVICE_TIMESYNC 55U
#endif
/* SIG_RR_SomeipTsyncSyncGnssOsClockDiv_return_Cis_ECU1_Service_TimeSync */
#if !defined(RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCSYNCGNSSOSCLOCKDIV_RETURN_CIS_ECU1_SERVICE_TIMESYNC)
#define RTE_LDCOM_SIGIPDU_RR_SOMEIPTSYNCSYNCGNSSOSCLOCKDIV_RETURN_CIS_ECU1_SERVICE_TIMESYNC 56U
#endif
/* SIG_RR_TransCfgFile_return_Cis_ECU1_Service_CfgManage */
#if !defined(RTE_LDCOM_SIGIPDU_RR_TRANSCFGFILE_RETURN_CIS_ECU1_SERVICE_CFGMANAGE)
#define RTE_LDCOM_SIGIPDU_RR_TRANSCFGFILE_RETURN_CIS_ECU1_SERVICE_CFGMANAGE 57U
#endif
/* SIG_RR_UpdateChnlConfig_return_Cis_ECU1_NrmComCtrChnlConfig */
#if !defined(RTE_LDCOM_SIGIPDU_RR_UPDATECHNLCONFIG_RETURN_CIS_ECU1_NRMCOMCTRCHNLCONFIG)
#define RTE_LDCOM_SIGIPDU_RR_UPDATECHNLCONFIG_RETURN_CIS_ECU1_NRMCOMCTRCHNLCONFIG 58U
#endif

extern VAR(str_rte_proxy_buff, AUTOMATIC) rte_buffer_ldComTxProxy_EcucPartition_C1_APP_QM[ECUCPARTITION_C1_APP_QM_LDCOMPERIODPROXYTX_SIZE];

extern FUNC(void, RTE_CODE) ProxyEntity(P2VAR(str_rte_proxy_buff, AUTOMATIC, RTE_APPL_DATA) proxyBuffer, VAR(uint16, AUTOMATIC) len);
extern FUNC(void, RTE_CODE) Rte_LdComSendProxy_AssembleData(P2VAR(str_rte_proxy_buff, AUTOMATIC, RTE_APPL_DATA) proxyBuffer, VAR(uint16, AUTOMATIC) len, VAR(boolean, AUTOMATIC) isPeridProxy);
extern FUNC(void, RTE_CODE) Rte_LdComSendProxyQueueData_AssembleData(P2VAR(str_rte_proxy_buff, AUTOMATIC, RTE_APPL_DATA) proxyBuffer, P2VAR(boolean, AUTOMATIC, RTE_APPL_DATA) hasAnySignalQueued, VAR(uint16, AUTOMATIC) len, VAR(boolean, AUTOMATIC) isPeridProxy);
extern FUNC(boolean, RTE_CODE) Rte_LdComProxySendCheckDataIsUpdate(P2VAR(str_rte_proxy_buff, AUTOMATIC, RTE_APPL_DATA) signalData);

#endif /* RTE_PROXY_H */