/**
 * \file Crypto_11_Hsm_Cfg.h for AUTOSAR 4.3.1.
 * \copyright (c) ESCRYPT GmbH, Bochum, Germany 2019. All rights reserved, also regarding any disposal, exploitation,
 *                  reproduction, editing, distribution, as well as in the event of applications for industrial property
 *                  rights.
 *
 * +---------------------------------------------------------------------------------------+
 * | This file has been generated automatically. Don't modify as all changes will be lost. |
 * +---------------------------------------------------------------------------------------+
 */

/* Global QA-C suppression */
/* PRQA S 0776, 0778 EOF # Deviation ID directive_1.1_0776_0778 */
/* PRQA S 0292 EOF # Deviation ID directive_1.1_0292 */
/* PRQA S 0857 EOF # Deviation ID directive_1.1_0857 */
/* PRQA S 2053 EOF # Deviation ID rule_18.8_2053 */
/* PRQA S 3214 EOF # Suppressed because of the ASR memmap concept */
/* PRQA S 2000 EOF # Suppressed for simplicity. Not necessary having else statement is allowed. */
/* PRQA S 5002 EOF # Suppressed as header file names are defined by ASR. */
/* PRQA S 0777 EOF # Length of defines depends on name chosen by customer */

#ifndef CRYPTO_11_HSM_CFG_H
#define CRYPTO_11_HSM_CFG_H
/** \req [$Satisfies $SWS_Crypto 00008] File structure */

#include <Platform_Types.h>
#include <Compiler.h>

#define CRYPTO_11_HSM_RELEASE_TYPE_d                        10u     /* DEBUG                */
#define CRYPTO_11_HSM_RELEASE_TYPE_a                        20u     /* ALPHA                */
#define CRYPTO_11_HSM_RELEASE_TYPE_b                        30u     /* BETA                 */
#define CRYPTO_11_HSM_RELEASE_TYPE_rc                       40u     /* RELEASE-CANDIDATE    */
#define CRYPTO_11_HSM_RELEASE_TYPE_r                        50u     /* RELEASE              */

#define CRYPTO_11_HSM_VENDOR_ID                             0x000Bu
#define CRYPTO_11_HSM_MODULE_ID                             114u
#define CRYPTO_11_HSM_INSTANCE_ID                           0u
#define CRYPTO_11_HSM_AR_RELEASE_MAJOR_VERSION              4u
#define CRYPTO_11_HSM_AR_RELEASE_MINOR_VERSION              3u
#define CRYPTO_11_HSM_AR_RELEASE_REVISION_VERSION           1u
#define CRYPTO_11_HSM_GEN_VERSION_MAIN                      1u
#define CRYPTO_11_HSM_GEN_VERSION_MAJOR                     2u
#define CRYPTO_11_HSM_GEN_VERSION_MINOR                     2u
#define CRYPTO_11_HSM_GEN_RELEASE_TYPE                      "r"
#define CRYPTO_11_HSM_GEN_RELEASE_TYPE_I                    CRYPTO_11_HSM_RELEASE_TYPE_r
#define CRYPTO_11_HSM_GEN_VERSION_PATCH                     0u

#define CRYPTO_11_HSM_CONFIG_ENABLE_EXTENSION               STD_OFF
#define CRYPTO_11_HSM_CONFIG_ENABLE_MDK                     STD_OFF

#define CRYPTO_11_HSM_VERSION_INFO_API                      STD_ON
#ifndef CRYPTO_11_HSM_DEV_ERROR_DETECT
#define CRYPTO_11_HSM_DEV_ERROR_DETECT                      STD_ON
#endif
#define CRYPTO_11_HSM_PRE_CONFIGURED                        STD_ON

#define CRYPTO_11_HSM_VALIDATE_AFTER_KEYEX                  STD_ON

#define CRYPTO_11_HSM_USE_V4_3_0_JOBTYPE_FIELD_NAMES        STD_OFF

#define CRYPTO_11_HSM_USE_AUTOSAR_4_4_0_EXTENSIONS          STD_ON

/* The number of sessions to attempt to open for each main function call.
 * Smaller number results in faster main function. Larger number give shorter time before crypto driver is ready to use. */
#define CRYPTO_11_HSM_CONFIG_NUM_SESSIONS_OPEN_PER_CALL     15u

#define CRYPTO_11_HSM_CONFIG_CRYPTO_PRIMITIVE_COUNT                     3u
#define CRYPTO_11_HSM_CONFIG_CRYPTO_OBJECT_COUNT                        2u
#define CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_COUNT                           110u
#define CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_ELEMENT_COUNT                   110u
#define CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_TYPE_ELEMENT_REFERENCES_COUNT   110u
#define CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_TYPE_COUNT                      110u
#define CRYPTO_11_HSM_CONFIG_HSM_KEY_COUNT                              110u
#define CRYPTO_11_HSM_ELEMENT_TO_HSM_KEY_UNIQUE                         STD_ON
#define CRYPTO_11_HSM_CONFIG_KEY_RELEASE_STRATEGY                       CRYPTO_11_HSM_KEY_RELEASE_STRATEGY_LOW_PRIO_FIRST_PREFER_SAME_TYPE
#define CRYPTO_11_HSM_CONFIG_KEY_MANAGEMENT_PRIORITY                    3u

/* Normally 200u should be enough */
#define CRYPTO_11_HSM_CONFIG_KEYM_CSAI_TIMEOUT_MS                            2000u
/* ECDH operations demand a longer waiting time */
#define CRYPTO_11_HSM_CONFIG_KEYM_CSAI_KEY_EXCHANGE_TIMEOUT_MS               2000u
/* Writing to flash can take a 'significant' period (longer than 'typical' limit below) due to potential
 * flash file system reorganisation. Performance can vary with target, flash condition temperature etc */
#define CRYPTO_11_HSM_CONFIG_KEYM_CSAI_DFLASH_WRITE_TIMEOUT_MS               800u

#define CRYPTO_11_HSM_INIT_STATE_TIMEOUT_MSEC                           1000u

#define CRYPTO_11_HSM_PROCESS_JOB_TIMEOUT_MSEC                          4000u

/* Maximum time allowed to inject (and potentially store) an HSM key. A timeout will occur if this time is exceeded */
#define CRYPTO_11_HSM_SET_KEY_TIMEOUT_MSEC                              1000u
#define CRYPTO_11_HSM_CONFIG_CLOCK_DIVIDER                  1u /* TODO: Add this value to ParamDef */

#define CRYPTO_11_HSM_CONFIG_HAS_SHE_SERVICES               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_SHE_KEY_MGMT               STD_OFF
/* PRQA S 4800 4 #External functions need not conform to naming rules of the crypto driver */
extern FUNC(void, CRYPTO_11_HSM_CODE) CalloutFunctionGetCounterValue(
    CONSTP2VAR(uint32, AUTOMATIC, AUTOMATIC) pValue);
extern FUNC(void, CRYPTO_11_HSM_CODE) CalloutFunctionGetElapsedCounterValue(
    CONST(uint32, AUTOMATIC) value, CONSTP2VAR(uint32, AUTOMATIC, AUTOMATIC) pElapsedValue);

#define CRYPTO_11_HSM_CALLOUT_GET_MILLISEC         CalloutFunctionGetCounterValue
#define CRYPTO_11_HSM_CALLOUT_GET_ELAPSED_MILLISEC CalloutFunctionGetElapsedCounterValue

#define CRYPTO_11_HSM_TICKS_CALLOUTS                        STD_OFF
#define CRYPTO_11_HSM_TIMER_UNIT_FOR_SYNC_JOBS              CRYPTO_11_HSM_MS
#define CRYPTO_11_HSM_TIMER_UNIT_FOR_ASYNC_JOBS             CRYPTO_11_HSM_MS

#define CRYPTO_11_HSM_CONFIG_HAS_HASH                       STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_MACGENERATE                STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_MACVERIFY                  STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_ENCRYPT                    STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_DECRYPT                    STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_AEADENCRYPT                STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_AEADDECRYPT                STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_SIGNATUREGENERATE          STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_SIGNATUREVERIFY            STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_RANDOMGENERATE             STD_OFF

#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA1               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_224           STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_256           STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_384           STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_512           STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_512_224       STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SHA2_512_256       STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_AES                STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_RSA                STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_ED25519            STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_ECCNIST            STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_RNG                STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOFAM_SIPHASH            STD_OFF

#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_ECB               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_CBC               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_CFB               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_OFB               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_CTR               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_GCM               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_XTS               STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_RSAES_OAEP        STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_RSAES_PKCS1_v1_5  STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_RSASSA_PSS        STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_RSASSA_PKCS1_v1_5 STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_8ROUNDS           STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_12ROUNDS          STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_20ROUNDS          STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_HMAC              STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_CMAC              STD_ON
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_GMAC              STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_CTRDRBG           STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_SIPHASH_2_4       STD_OFF
#define CRYPTO_11_HSM_CONFIG_HAS_ALGOMODE_SIPHASH_4_8       STD_OFF


#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_BASE_0_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_1_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_2_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_3_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_BASE_0_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_1_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_2_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_3_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_4_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_5_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_6_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_7_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_8_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_9_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MAXUPDATE3_0_BUFFER_SIZE    16u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_BASE_0_BUFFER_SIZE    256u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_1_BUFFER_SIZE    256u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_2_BUFFER_SIZE    256u
#define CRYPTO_11_HSM_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_3_BUFFER_SIZE    256u

#define CRYPTO_11_HSM_START_SEC_CONST_32
#include <Crypto_11_Hsm_MemMap.h>


#define CRYPTO_11_HSM_STOP_SEC_CONST_32
/* PRQA S 5087 1 #File inclusion is inline with Autosar Memmap concept */
#include <Crypto_11_Hsm_MemMap.h>

/* Defines to access crypto driver objects explicitly */
/* PRQA S 4800 ++ # Name rule is required by AUTOSAR implementations */
#define CryptoConf_CryptoDriverObject_CryptoDriverObject    0
#define CryptoConf_CryptoDriverObject_CryptoDriverObject_Verify    1
/* PRQA S 4800 -- */

/* Defines to access crypto keys explicitly */
/* PRQA S 4800 ++ # Name rule is required by AUTOSAR implementations */
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_VOLATILE_BASIC_SHE_SECRET_KEY 0
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_VOLATILE_BASIC_SHE_RAM_KEY 1
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_VOLATILE_BASIC_SHE_RESERVED_KEY 2
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_MASTER_KEY 3
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_BOOT_KEY 4
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_MAC_KEY 5
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_BASE_0 6
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_1 7
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_2 8
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_3 9
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_4 10
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_5 11
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_6 12
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_7 13
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_8 14
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_9 15
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_BASE_0 16
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_1 17
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_2 18
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_3 19
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_4 20
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_5 21
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_6 22
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_7 23
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_8 24
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_9 25
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_10 26
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_11 27
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_12 28
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_13 29
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_14 30
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_15 31
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_16 32
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_17 33
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_18 34
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_19 35
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_20 36
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_21 37
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_22 38
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_23 39
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_24 40
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_25 41
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_26 42
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_27 43
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_28 44
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_29 45
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_30 46
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_31 47
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_32 48
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_33 49
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_34 50
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_35 51
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_36 52
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_37 53
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_38 54
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_39 55
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_BASE_0 56
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_1 57
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_2 58
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_3 59
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_4 60
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_5 61
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_6 62
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_7 63
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_8 64
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_9 65
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_10 66
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_11 67
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_12 68
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_13 69
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_14 70
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_15 71
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_16 72
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_17 73
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_18 74
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_19 75
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_20 76
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_21 77
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_22 78
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_23 79
#define CryptoConf_CryptoKey_CryptoKey_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_24 80
#define CryptoConf_CryptoKey_CryptoKey_RSA_KEY_DYNAMIC_CFG_RSA_PUBLIC_KEY 81
#define CryptoConf_CryptoKey_CryptoKey_RSA_KEY_DYNAMIC_CFG_RSA_KEY_PAIR 82
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_KEY_PAIR 83
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_PUBLIC_KEY 84
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_PRIVATE_KEY 85
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_PUBLIC_KEY_ECDSA 86
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_PRIVATE_KEY_ECDSA 87
#define CryptoConf_CryptoKey_CryptoKey_ECC_KEY_DYNAMIC_ECC_KEY_PAIR_ECDSA 88
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_BASE_0 89
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_1 90
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_2 91
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_3 92
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_BASE_0 93
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_1 94
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_2 95
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_3 96
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_4 97
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_5 98
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_6 99
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_7 100
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_8 101
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_9 102
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_READONLY_0 103
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MAXUPDATE3_0 104
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_BASE_0 105
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_1 106
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_2 107
#define CryptoConf_CryptoKey_CryptoKey_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_3 108
#define CryptoConf_CryptoKey_CryptoKey_INT_DATA_STATIC_CFG_INT_DATA_0 109
/* PRQA S 4800 -- */

/* Defines to access crypto key element id explicitly */
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_VOLATILE_BASIC_SHE_SECRET_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_VOLATILE_BASIC_SHE_RAM_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_VOLATILE_BASIC_SHE_RESERVED_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_MASTER_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_BOOT_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_MAC_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_4_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_5_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_6_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_7_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_8_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_BASIC_SHE_DFLASH_KEY_INST_9_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_4_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_5_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_6_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_7_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_8_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_9_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_10_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_11_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_12_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_13_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_14_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_15_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_16_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_17_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_18_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_19_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_20_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_21_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_22_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_23_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_24_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_25_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_26_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_27_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_28_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_29_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_30_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_31_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_32_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_33_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_34_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_35_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_36_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_37_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_38_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_EXT_SHE_DFLASH_KEY_INST_39_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_4_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_5_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_6_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_7_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_8_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_9_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_10_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_11_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_12_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_13_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_14_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_15_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_16_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_17_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_18_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_19_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_20_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_21_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_22_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_23_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_AES_KEY_DYNAMIC_CFG_AES_KEY_0_INST_24_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_RSA_KEY_DYNAMIC_CFG_RSA_PUBLIC_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_RSA_KEY_DYNAMIC_CFG_RSA_KEY_PAIR_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_KEY_PAIR_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_PUBLIC_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_PRIVATE_KEY_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_PUBLIC_KEY_ECDSA_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_PRIVATE_KEY_ECDSA_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_ECC_KEY_DYNAMIC_ECC_KEY_PAIR_ECDSA_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MONOTONIC_0_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_4_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_5_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_6_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_7_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_8_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_SMALL_0_INST_9_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_READONLY_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_MAXUPDATE3_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_BASE_0_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_1_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_2_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_SECRET_DATA_DYNAMIC_CFG_SECRET_DATA_LARGE_0_INST_3_EL_ID 1u
#define CRYPTO_11_HSM_CRYPTO_KE_CRYPTOKEYEL_INT_DATA_STATIC_CFG_INT_DATA_0_EL_ID 1u

#endif /* CRYPTO_11_HSM_CFG_H */
