/**************************************************************************************
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2023. All rights reserved.
 * Description: Rte_MemMap.h
 * Author: VOS OS
 * Create: 2019-12-31
 *
 **************************************************************************************/
/**************************************************************************************
 *    Note:
 *    Adapte to HighTec compiler and GHS and llvm
 **************************************************************************************/
#define RTE_MEMMAP_ERROR

#if (defined(__ghs__))
#ifndef RTE_GHS_C_POWERPC
    #define RTE_GHS_C_POWERPC
#endif
#elif (defined(__clang__))
#ifndef RTE_LLVM_C_S32G
    #define RTE_LLVM_C_S32G
#endif
#elif (defined(__GNUC__))
#ifndef RTE_GNU_C_POWERPC
    #define RTE_GNU_C_POWERPC
#endif
#endif

/******************************************************************************
            Rte  memory mapping code section
            Global shared code.
 ******************************************************************************/
#ifdef RTE_START_SEC_CODE
#undef RTE_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_api_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_text" ax
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_api_text"
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CODE
#undef RTE_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#endif
#else
#error No section "rte_api_text" started
#endif
#endif

/******************************************************************************
            Rte  memory mapping code section
            SchM API code
 ******************************************************************************/
#ifdef SCHM_START_SEC_CODE
#undef SCHM_START_SEC_CODE
#ifdef SCHM_OPEN_SECTION
#error Starting a "schm_api_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="schm_api_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "schm_api_text" ax
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="schm_api_text"
#endif
#define SCHM_OPEN_SECTION
#endif
#endif

#ifdef SCHM_STOP_SEC_CODE
#undef SCHM_STOP_SEC_CODE
#ifdef SCHM_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef SCHM_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#endif
#else
#error No section "schm_api_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Global shared constants alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_CONST_8
#undef RTE_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_api_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_api_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CONST_8
#undef RTE_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_CALIB_8
#undef RTE_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_api_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_api_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CALIB_8
#undef RTE_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_const_8" started
#endif
#endif
/******************************************************************************
    Global shared variables INIT alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_8
#undef RTE_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_8" bss="rte_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_8
#undef RTE_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_8" started
#endif
#endif
/******************************************************************************
    Global shared variables CLEARED alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_8
#undef RTE_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_8
#undef RTE_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_8" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables INIT alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_api_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_api_data_8" bss="rte_calib_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_data_8" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables CLEARED alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_api_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_bss_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Global shared constants alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_CONST_16
#undef RTE_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_api_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_api_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CONST_16
#undef RTE_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_CALIB_16
#undef RTE_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_api_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_api_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CALIB_16
#undef RTE_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_const_16" started
#endif
#endif
/******************************************************************************
    Global shared variables INIT alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_16
#undef RTE_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_16" bss="rte_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_16
#undef RTE_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_16" started
#endif
#endif
/******************************************************************************
    Global shared variables CLEARED alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_16
#undef RTE_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_16
#undef RTE_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_16" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables INIT alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_api_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_api_data_16" bss="rte_calib_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_data_16" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables CLEARED alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_api_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_bss_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Global shared constants alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_CONST_32
#undef RTE_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_api_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_api_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CONST_32
#undef RTE_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_CALIB_32
#undef RTE_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_api_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_api_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CALIB_32
#undef RTE_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_const_32" started
#endif
#endif
/******************************************************************************
    Global shared variables INIT alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_32
#undef RTE_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_32" bss="rte_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_32
#undef RTE_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_32" started
#endif
#endif
/******************************************************************************
    Global shared variables CLEARED alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_32
#undef RTE_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_32
#undef RTE_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_32" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables INIT alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_api_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_api_data_32" bss="rte_calib_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_data_32" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables CLEARED alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_api_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_bss_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Global shared constants alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_CONST_64
#undef RTE_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_api_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_api_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CONST_64
#undef RTE_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_CALIB_64
#undef RTE_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_api_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_api_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CALIB_64
#undef RTE_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_const_64" started
#endif
#endif
/******************************************************************************
    Global shared variables INIT alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_64
#undef RTE_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_64" bss="rte_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_64
#undef RTE_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_64" started
#endif
#endif
/******************************************************************************
    Global shared variables CLEARED alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_64
#undef RTE_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_64
#undef RTE_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_64" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables INIT alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_api_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_api_data_64" bss="rte_calib_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_data_64" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables CLEARED alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_api_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_bss_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Global shared constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_CONST_UNSPECIFIED
#undef RTE_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_api_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_api_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_CALIB_UNSPECIFIED
#undef RTE_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_api_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_api_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_const_unspecified" started
#endif
#endif
/******************************************************************************
    Global shared variables INIT alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_unspecified" bss="rte_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_unspecified" started
#endif
#endif
/******************************************************************************
    Global shared variables CLEARED alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables INIT alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_api_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_api_data_unspecified" bss="rte_calib_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_data_unspecified" started
#endif
#endif
/******************************************************************************
    Global shared calibration variables CLEARED alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_api_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_api_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_api_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_api_bss_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C0_1_HW_QM
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CODE
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C0_1_HW_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C0_1_HW_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CODE
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_1_HW_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_1_HW_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_1_HW_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_1_HW_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_8" bss="rte_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_1_HW_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_1_HW_QM_data_8" bss="rte_calib_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_1_HW_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_fast_8" bss="rte_OSA_C0_1_HW_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_slow_8" bss="rte_OSA_C0_1_HW_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_1_HW_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_1_HW_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_1_HW_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_1_HW_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_16" bss="rte_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_1_HW_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_1_HW_QM_data_16" bss="rte_calib_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_1_HW_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_fast_16" bss="rte_OSA_C0_1_HW_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_slow_16" bss="rte_OSA_C0_1_HW_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_1_HW_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_1_HW_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_1_HW_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_1_HW_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_32" bss="rte_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_1_HW_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_1_HW_QM_data_32" bss="rte_calib_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_1_HW_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_fast_32" bss="rte_OSA_C0_1_HW_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_slow_32" bss="rte_OSA_C0_1_HW_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_1_HW_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_1_HW_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_1_HW_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_1_HW_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_64" bss="rte_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_1_HW_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_1_HW_QM_data_64" bss="rte_calib_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_1_HW_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_fast_64" bss="rte_OSA_C0_1_HW_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_slow_64" bss="rte_OSA_C0_1_HW_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_1_HW_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_1_HW_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_1_HW_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_1_HW_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_unspecified" bss="rte_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_1_HW_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_1_HW_QM_data_unspecified" bss="rte_calib_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_1_HW_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_1_HW_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_1_HW_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_1_HW_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_fast_unspecified" bss="rte_OSA_C0_1_HW_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_1_HW_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_1_HW_QM_data_slow_unspecified" bss="rte_OSA_C0_1_HW_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_1_HW_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_1_HW_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_1_HW_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_1_HW_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_1_HW_QM_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C0_3_HW_ASILD
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CODE
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C0_3_HW_ASILD_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C0_3_HW_ASILD_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CODE
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_3_HW_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_3_HW_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_8" bss="rte_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_3_HW_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_3_HW_ASILD_data_8" bss="rte_calib_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_fast_8" bss="rte_OSA_C0_3_HW_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_slow_8" bss="rte_OSA_C0_3_HW_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_3_HW_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_3_HW_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_16" bss="rte_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_3_HW_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_3_HW_ASILD_data_16" bss="rte_calib_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_fast_16" bss="rte_OSA_C0_3_HW_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_slow_16" bss="rte_OSA_C0_3_HW_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_3_HW_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_3_HW_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_32" bss="rte_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_3_HW_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_3_HW_ASILD_data_32" bss="rte_calib_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_fast_32" bss="rte_OSA_C0_3_HW_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_slow_32" bss="rte_OSA_C0_3_HW_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_3_HW_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_3_HW_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_64" bss="rte_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_3_HW_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_3_HW_ASILD_data_64" bss="rte_calib_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_fast_64" bss="rte_OSA_C0_3_HW_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_slow_64" bss="rte_OSA_C0_3_HW_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C0_3_HW_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C0_3_HW_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C0_3_HW_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_unspecified" bss="rte_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C0_3_HW_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C0_3_HW_ASILD_data_unspecified" bss="rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C0_3_HW_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_fast_unspecified" bss="rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C0_3_HW_ASILD_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C0_3_HW_ASILD_data_slow_unspecified" bss="rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C0_3_HW_ASILD_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C1_1_APP_QM
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CODE
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C1_1_APP_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C1_1_APP_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CODE
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_8" bss="rte_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_1_APP_QM_data_8" bss="rte_calib_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_fast_8" bss="rte_OSA_C1_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_slow_8" bss="rte_OSA_C1_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_16" bss="rte_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_1_APP_QM_data_16" bss="rte_calib_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_fast_16" bss="rte_OSA_C1_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_slow_16" bss="rte_OSA_C1_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_32" bss="rte_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_1_APP_QM_data_32" bss="rte_calib_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_fast_32" bss="rte_OSA_C1_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_slow_32" bss="rte_OSA_C1_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_64" bss="rte_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_1_APP_QM_data_64" bss="rte_calib_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_fast_64" bss="rte_OSA_C1_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_slow_64" bss="rte_OSA_C1_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_unspecified" bss="rte_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_1_APP_QM_data_unspecified" bss="rte_calib_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_fast_unspecified" bss="rte_OSA_C1_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_1_APP_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_1_APP_QM_data_slow_unspecified" bss="rte_OSA_C1_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_1_APP_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_1_APP_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_1_APP_QM_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C1_2_APP_ASILD
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CODE
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C1_2_APP_ASILD_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C1_2_APP_ASILD_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CODE
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_8" bss="rte_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_2_APP_ASILD_data_8" bss="rte_calib_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_fast_8" bss="rte_OSA_C1_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_slow_8" bss="rte_OSA_C1_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_16" bss="rte_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_2_APP_ASILD_data_16" bss="rte_calib_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_fast_16" bss="rte_OSA_C1_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_slow_16" bss="rte_OSA_C1_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_32" bss="rte_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_2_APP_ASILD_data_32" bss="rte_calib_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_fast_32" bss="rte_OSA_C1_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_slow_32" bss="rte_OSA_C1_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_64" bss="rte_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_2_APP_ASILD_data_64" bss="rte_calib_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_fast_64" bss="rte_OSA_C1_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_slow_64" bss="rte_OSA_C1_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C1_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C1_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C1_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_unspecified" bss="rte_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C1_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C1_2_APP_ASILD_data_unspecified" bss="rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C1_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_fast_unspecified" bss="rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C1_2_APP_ASILD_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C1_2_APP_ASILD_data_slow_unspecified" bss="rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C1_2_APP_ASILD_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C2_1_APP_QM
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CODE
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C2_1_APP_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C2_1_APP_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CODE
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_8" bss="rte_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_1_APP_QM_data_8" bss="rte_calib_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_fast_8" bss="rte_OSA_C2_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_slow_8" bss="rte_OSA_C2_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_16" bss="rte_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_1_APP_QM_data_16" bss="rte_calib_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_fast_16" bss="rte_OSA_C2_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_slow_16" bss="rte_OSA_C2_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_32" bss="rte_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_1_APP_QM_data_32" bss="rte_calib_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_fast_32" bss="rte_OSA_C2_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_slow_32" bss="rte_OSA_C2_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_64" bss="rte_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_1_APP_QM_data_64" bss="rte_calib_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_fast_64" bss="rte_OSA_C2_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_slow_64" bss="rte_OSA_C2_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_unspecified" bss="rte_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_1_APP_QM_data_unspecified" bss="rte_calib_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_fast_unspecified" bss="rte_OSA_C2_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_1_APP_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_1_APP_QM_data_slow_unspecified" bss="rte_OSA_C2_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_1_APP_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_1_APP_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_1_APP_QM_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C2_2_APP_ASILD
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CODE
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C2_2_APP_ASILD_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C2_2_APP_ASILD_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CODE
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_8" bss="rte_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_2_APP_ASILD_data_8" bss="rte_calib_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_fast_8" bss="rte_OSA_C2_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_slow_8" bss="rte_OSA_C2_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_16" bss="rte_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_2_APP_ASILD_data_16" bss="rte_calib_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_fast_16" bss="rte_OSA_C2_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_slow_16" bss="rte_OSA_C2_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_32" bss="rte_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_2_APP_ASILD_data_32" bss="rte_calib_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_fast_32" bss="rte_OSA_C2_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_slow_32" bss="rte_OSA_C2_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_64" bss="rte_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_2_APP_ASILD_data_64" bss="rte_calib_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_fast_64" bss="rte_OSA_C2_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_slow_64" bss="rte_OSA_C2_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C2_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C2_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C2_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_unspecified" bss="rte_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C2_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C2_2_APP_ASILD_data_unspecified" bss="rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C2_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_fast_unspecified" bss="rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C2_2_APP_ASILD_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C2_2_APP_ASILD_data_slow_unspecified" bss="rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C2_2_APP_ASILD_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C3_1_APP_QM
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CODE
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C3_1_APP_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C3_1_APP_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CODE
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_8" bss="rte_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_1_APP_QM_data_8" bss="rte_calib_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_fast_8" bss="rte_OSA_C3_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_slow_8" bss="rte_OSA_C3_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_16" bss="rte_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_1_APP_QM_data_16" bss="rte_calib_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_fast_16" bss="rte_OSA_C3_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_slow_16" bss="rte_OSA_C3_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_32" bss="rte_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_1_APP_QM_data_32" bss="rte_calib_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_fast_32" bss="rte_OSA_C3_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_slow_32" bss="rte_OSA_C3_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_64" bss="rte_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_1_APP_QM_data_64" bss="rte_calib_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_fast_64" bss="rte_OSA_C3_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_slow_64" bss="rte_OSA_C3_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_unspecified" bss="rte_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_1_APP_QM_data_unspecified" bss="rte_calib_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_fast_unspecified" bss="rte_OSA_C3_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_1_APP_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_1_APP_QM_data_slow_unspecified" bss="rte_OSA_C3_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_1_APP_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_1_APP_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_1_APP_QM_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C3_2_APP_ASILD
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CODE
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C3_2_APP_ASILD_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C3_2_APP_ASILD_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CODE
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_8" bss="rte_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_2_APP_ASILD_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_2_APP_ASILD_data_8" bss="rte_calib_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_fast_8" bss="rte_OSA_C3_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_slow_8" bss="rte_OSA_C3_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_16" bss="rte_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_2_APP_ASILD_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_2_APP_ASILD_data_16" bss="rte_calib_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_fast_16" bss="rte_OSA_C3_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_slow_16" bss="rte_OSA_C3_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_32" bss="rte_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_2_APP_ASILD_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_2_APP_ASILD_data_32" bss="rte_calib_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_fast_32" bss="rte_OSA_C3_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_slow_32" bss="rte_OSA_C3_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_64" bss="rte_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_2_APP_ASILD_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_2_APP_ASILD_data_64" bss="rte_calib_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_fast_64" bss="rte_OSA_C3_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_slow_64" bss="rte_OSA_C3_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C3_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C3_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C3_2_APP_ASILD_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_unspecified" bss="rte_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C3_2_APP_ASILD_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C3_2_APP_ASILD_data_unspecified" bss="rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C3_2_APP_ASILD_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_fast_unspecified" bss="rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C3_2_APP_ASILD_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C3_2_APP_ASILD_data_slow_unspecified" bss="rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C3_2_APP_ASILD_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C4_1_APP_QM
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CODE
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C4_1_APP_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C4_1_APP_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CODE
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C4_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C4_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C4_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C4_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_8" bss="rte_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C4_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C4_1_APP_QM_data_8" bss="rte_calib_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C4_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_fast_8" bss="rte_OSA_C4_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_slow_8" bss="rte_OSA_C4_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C4_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C4_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C4_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C4_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_16" bss="rte_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C4_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C4_1_APP_QM_data_16" bss="rte_calib_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C4_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_fast_16" bss="rte_OSA_C4_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_slow_16" bss="rte_OSA_C4_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C4_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C4_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C4_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C4_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_32" bss="rte_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C4_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C4_1_APP_QM_data_32" bss="rte_calib_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C4_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_fast_32" bss="rte_OSA_C4_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_slow_32" bss="rte_OSA_C4_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C4_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C4_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C4_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C4_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_64" bss="rte_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C4_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C4_1_APP_QM_data_64" bss="rte_calib_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C4_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_fast_64" bss="rte_OSA_C4_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_slow_64" bss="rte_OSA_C4_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C4_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C4_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C4_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C4_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_unspecified" bss="rte_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C4_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C4_1_APP_QM_data_unspecified" bss="rte_calib_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C4_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C4_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C4_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C4_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_fast_unspecified" bss="rte_OSA_C4_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C4_1_APP_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C4_1_APP_QM_data_slow_unspecified" bss="rte_OSA_C4_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C4_1_APP_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C4_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C4_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C4_1_APP_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C4_1_APP_QM_bss_slow_unspecified" started
#endif
#endif

/******************************************************************************
    Application specific Rte code partition: OSA_C5_1_APP_QM
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CODE
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CODE
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_text" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section text="rte_OSA_C5_1_APP_QM_text"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text="rte_OSA_C5_1_APP_QM_text"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_text" ax
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CODE
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CODE
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section text=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_text" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C5_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C5_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_const_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C5_1_APP_QM_const_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C5_1_APP_QM_const_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_const_8" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_const_8" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_8" bss="rte_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C5_1_APP_QM_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C5_1_APP_QM_data_8" bss="rte_calib_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_data_8" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C5_1_APP_QM_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_bss_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_fast_8" bss="rte_OSA_C5_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_slow_8" bss="rte_OSA_C5_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 8
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C5_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C5_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_const_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C5_1_APP_QM_const_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C5_1_APP_QM_const_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_const_16" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_const_16" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_16" bss="rte_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C5_1_APP_QM_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C5_1_APP_QM_data_16" bss="rte_calib_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_data_16" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C5_1_APP_QM_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_bss_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_fast_16" bss="rte_OSA_C5_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_slow_16" bss="rte_OSA_C5_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 16
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C5_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C5_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_const_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C5_1_APP_QM_const_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C5_1_APP_QM_const_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_const_32" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_const_32" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_32" bss="rte_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C5_1_APP_QM_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C5_1_APP_QM_data_32" bss="rte_calib_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_data_32" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C5_1_APP_QM_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_bss_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_fast_32" bss="rte_OSA_C5_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_slow_32" bss="rte_OSA_C5_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 32
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C5_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C5_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_const_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C5_1_APP_QM_const_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C5_1_APP_QM_const_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_const_64" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_const_64" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_64" bss="rte_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C5_1_APP_QM_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C5_1_APP_QM_data_64" bss="rte_calib_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_data_64" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C5_1_APP_QM_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_bss_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_fast_64" bss="rte_OSA_C5_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_slow_64" bss="rte_OSA_C5_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: 64
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Application specific constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_OSA_C5_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_OSA_C5_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CONST_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Rte  memory mapping const section Calibration constants alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_const_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section rodata="rte_calib_OSA_C5_1_APP_QM_const_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata="rte_calib_OSA_C5_1_APP_QM_const_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_const_unspecified" a
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_CALIB_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section rodata=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_const_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables INIT Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_unspecified" bss="rte_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables CLEARED Only application members and other trusted OSA may have access to them.
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables INIT
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_calib_OSA_C5_1_APP_QM_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_calib_OSA_C5_1_APP_QM_data_unspecified" bss="rte_calib_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application private calibration variables CLEARED
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_calib_OSA_C5_1_APP_QM_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_calib_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_calib_OSA_C5_1_APP_QM_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_calib_OSA_C5_1_APP_QM_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INTERNAL_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_calib_OSA_C5_1_APP_QM_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_fast_unspecified" bss="rte_OSA_C5_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into fast RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_OSA_C5_1_APP_QM_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_OSA_C5_1_APP_QM_data_slow_unspecified" bss="rte_OSA_C5_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application private variables intended to be linked into slow RAM
    alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_OSA_C5_1_APP_QM_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_OSA_C5_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_OSA_C5_1_APP_QM_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_OSA_C5_1_APP_QM_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_OSA_C5_1_APP_QM_bss_slow_unspecified" started
#endif
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_1_HW_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C0_3_HW_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C1_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C2_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C3_2_APP_ASILD_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C4_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_8_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_16_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_32_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_64_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_FAST_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_INIT_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_START_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

#ifdef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#undef RTE_OSA_C5_1_APP_QM_STOP_SEC_VAR_SLOW_CLEARED_UNSPECIFIED_QM_GLOBAL
#define RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#endif

/******************************************************************************
    Application shared memory section: QM
 ******************************************************************************/
/******************************************************************************
    Application shared variables INIT alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_8" bss="rte_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_8" started
#endif
#endif
/******************************************************************************
    Application shared variables CLEARED alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_8" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_fast_8" bss="rte_api_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_fast_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_fast_8" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_fast_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_fast_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_fast_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_fast_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_fast_8" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_slow_8" bss="rte_api_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_slow_8" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_INIT_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_slow_8" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 8
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_slow_8" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_slow_8"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_slow_8"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_slow_8" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_8_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_slow_8" started
#endif
#endif
/******************************************************************************
    Application shared variables INIT alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_16" bss="rte_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_16" started
#endif
#endif
/******************************************************************************
    Application shared variables CLEARED alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_16" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_fast_16" bss="rte_api_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_fast_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_fast_16" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_fast_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_fast_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_fast_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_fast_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_fast_16" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_slow_16" bss="rte_api_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_slow_16" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_INIT_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_slow_16" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 16
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_slow_16" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_slow_16"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_slow_16"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_slow_16" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_16_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_slow_16" started
#endif
#endif
/******************************************************************************
    Application shared variables INIT alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_32" bss="rte_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_32" started
#endif
#endif
/******************************************************************************
    Application shared variables CLEARED alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_32" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_fast_32" bss="rte_api_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_fast_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_fast_32" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_fast_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_fast_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_fast_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_fast_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_fast_32" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_slow_32" bss="rte_api_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_slow_32" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_INIT_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_slow_32" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 32
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_slow_32" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_slow_32"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_slow_32"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_slow_32" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_32_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_slow_32" started
#endif
#endif
/******************************************************************************
    Application shared variables INIT alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_64" bss="rte_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_64" started
#endif
#endif
/******************************************************************************
    Application shared variables CLEARED alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_64" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_fast_64" bss="rte_api_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_fast_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_fast_64" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_fast_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_fast_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_fast_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_fast_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_fast_64" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_slow_64" bss="rte_api_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_slow_64" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_INIT_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_slow_64" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: 64
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_slow_64" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_slow_64"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_slow_64"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_slow_64" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_64_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_slow_64" started
#endif
#endif
/******************************************************************************
    Application shared variables INIT alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_unspecified" bss="rte_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_unspecified" started
#endif
#endif
/******************************************************************************
    Application shared variables CLEARED alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_unspecified" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_fast_unspecified" bss="rte_api_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_fast_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into fast RAM alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_fast_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_fast_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_fast_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_fast_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_FAST_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_fast_unspecified" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_data_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section data="rte_api_data_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="rte_api_data_slow_unspecified" bss="rte_api_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_data_slow_unspecified" aw
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_INIT_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section data="" bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_data_slow_unspecified" started
#endif
#endif
/******************************************************************************
    Application shared variables intended to be linked into slow RAM alignment: UNSPECIFIED
 ******************************************************************************/
#ifdef RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_START_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#error Starting a "rte_api_bss_slow_unspecified" section while a section is already started
#else
#undef RTE_MEMMAP_ERROR
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section bss="rte_api_bss_slow_unspecified"
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss="rte_api_bss_slow_unspecified"
#elif defined RTE_GNU_C_POWERPC
    #pragma section "rte_api_bss_slow_unspecified" awB
#endif
#define RTE_OPEN_SECTION
#endif
#endif

#ifdef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#undef RTE_STOP_SEC_VAR_SLOW_CLEARED_QM_UNSPECIFIED_GLOBAL
#ifdef RTE_OPEN_SECTION
#undef RTE_MEMMAP_ERROR
#undef RTE_OPEN_SECTION
#ifdef RTE_GHS_C_POWERPC
    #pragma ghs section
#elif defined RTE_LLVM_C_S32G
    #pragma clang section bss=""
#elif defined RTE_GNU_C_POWERPC
    #pragma section
#endif
#else
#error No section "rte_api_bss_slow_unspecified" started
#endif
#endif

/* Check if the "command macro" has been acknowledged */
#ifdef RTE_MEMMAP_ERROR
#error Wrong Rte_MemMap.h inclusion command macro!
#endif